@@ -26,12 +26,11 @@ import shutil
 import signal
 import sys
 import threading
-import warnings
 from pathlib import Path
 from types import ModuleType
-from typing import Any, Optional, Union
+from typing import Any
 
-from huggingface_hub import try_to_load_from_cache
+from huggingface_hub import is_offline_mode, try_to_load_from_cache
 from packaging import version
 
 from .utils import (
@@ -39,7 +38,6 @@ from .utils import (
     TRANSFORMERS_DYNAMIC_MODULE_NAME,
     cached_file,
     extract_commit_hash,
-    is_offline_mode,
     logging,
 )
 from .utils.import_utils import VersionComparison, split_package_version
@@ -100,7 +98,7 @@ def init_hf_modules():
         importlib.invalidate_caches()
 
 
-def create_dynamic_module(name: Union[str, os.PathLike]) -> None:
+def create_dynamic_module(name: str | os.PathLike) -> None:
     """
     Creates a dynamic module in the cache directory for modules.
 
@@ -122,7 +120,7 @@ def create_dynamic_module(name: Union[str, os.PathLike]) -> None:
         importlib.invalidate_caches()
 
 
-def get_relative_imports(module_file: Union[str, os.PathLike]) -> list[str]:
+def get_relative_imports(module_file: str | os.PathLike) -> list[str]:
     """
     Get the list of modules that are relatively imported in a module file.
 
@@ -143,7 +141,7 @@ def get_relative_imports(module_file: Union[str, os.PathLike]) -> list[str]:
     return list(set(relative_imports))
 
 
-def get_relative_import_files(module_file: Union[str, os.PathLike]) -> list[str]:
+def get_relative_import_files(module_file: str | os.PathLike) -> list[str]:
     """
     Get the list of all files that are needed for a given module. Note that this function recurses through the relative
     imports (if a imports b and b imports c, it will return module files for b and c).
@@ -175,7 +173,7 @@ def get_relative_import_files(module_file: Union[str, os.PathLike]) -> list[str]
     return all_relative_imports
 
 
-def get_imports(filename: Union[str, os.PathLike]) -> list[str]:
+def get_imports(filename: str | os.PathLike) -> list[str]:
     """
     Extracts all the libraries (not relative imports this time) that are imported in a file.
 
@@ -230,7 +228,7 @@ def get_imports(filename: Union[str, os.PathLike]) -> list[str]:
     return sorted(imported_modules)
 
 
-def check_imports(filename: Union[str, os.PathLike]) -> list[str]:
+def check_imports(filename: str | os.PathLike) -> list[str]:
     """
     Check if the current Python environment contains all the libraries that are imported in a file. Will raise if a
     library is missing.
@@ -267,7 +265,7 @@ def check_imports(filename: Union[str, os.PathLike]) -> list[str]:
 
 def get_class_in_module(
     class_name: str,
-    module_path: Union[str, os.PathLike],
+    module_path: str | os.PathLike,
     *,
     force_reload: bool = False,
 ) -> type:
@@ -292,7 +290,7 @@ def get_class_in_module(
         if force_reload:
             sys.modules.pop(name, None)
             importlib.invalidate_caches()
-        cached_module: Optional[ModuleType] = sys.modules.get(name)
+        cached_module: ModuleType | None = sys.modules.get(name)
         module_spec = importlib.util.spec_from_file_location(name, location=module_file)
 
         # Hash the module file and all its relative imports to check if we need to reload it
@@ -314,17 +312,16 @@ def get_class_in_module(
 
 
 def get_cached_module_file(
-    pretrained_model_name_or_path: Union[str, os.PathLike],
+    pretrained_model_name_or_path: str | os.PathLike,
     module_file: str,
-    cache_dir: Optional[Union[str, os.PathLike]] = None,
+    cache_dir: str | os.PathLike | None = None,
     force_download: bool = False,
-    resume_download: Optional[bool] = None,
-    proxies: Optional[dict[str, str]] = None,
-    token: Optional[Union[bool, str]] = None,
-    revision: Optional[str] = None,
+    proxies: dict[str, str] | None = None,
+    token: bool | str | None = None,
+    revision: str | None = None,
     local_files_only: bool = False,
-    repo_type: Optional[str] = None,
-    _commit_hash: Optional[str] = None,
+    repo_type: str | None = None,
+    _commit_hash: str | None = None,
     **deprecated_kwargs,
 ) -> str:
     """
@@ -348,9 +345,6 @@ def get_cached_module_file(
         force_download (`bool`, *optional*, defaults to `False`):
             Whether or not to force to (re-)download the configuration files and override the cached versions if they
             exist.
-        resume_download:
-            Deprecated and ignored. All downloads are now resumed by default when possible.
-            Will be removed in v5 of Transformers.
         proxies (`dict[str, str]`, *optional*):
             A dictionary of proxy servers to use by protocol or endpoint, e.g., `{'http': 'foo.bar:3128',
             'http://hostname': 'foo.bar:4012'}.` The proxies are used on each request.
@@ -375,16 +369,6 @@ def get_cached_module_file(
     Returns:
         `str`: The path to the module inside the cache.
     """
-    use_auth_token = deprecated_kwargs.pop("use_auth_token", None)
-    if use_auth_token is not None:
-        warnings.warn(
-            "The `use_auth_token` argument is deprecated and will be removed in v5 of Transformers. Please use `token` instead.",
-            FutureWarning,
-        )
-        if token is not None:
-            raise ValueError("`token` and `use_auth_token` are both specified. Please set only the argument `token`.")
-        token = use_auth_token
-
     if is_offline_mode() and not local_files_only:
         logger.info("Offline mode: forcing local_files_only=True")
         local_files_only = True
@@ -409,7 +393,6 @@ def get_cached_module_file(
             cache_dir=cache_dir,
             force_download=force_download,
             proxies=proxies,
-            resume_download=resume_download,
             local_files_only=local_files_only,
             token=token,
             revision=revision,
@@ -469,7 +452,6 @@ def get_cached_module_file(
                     f"{Path(module_file).parent / module_needed}.py",
                     cache_dir=cache_dir,
                     force_download=force_download,
-                    resume_download=resume_download,
                     proxies=proxies,
                     token=token,
                     revision=revision,
@@ -493,16 +475,15 @@ def get_cached_module_file(
 
 def get_class_from_dynamic_module(
     class_reference: str,
-    pretrained_model_name_or_path: Union[str, os.PathLike],
-    cache_dir: Optional[Union[str, os.PathLike]] = None,
+    pretrained_model_name_or_path: str | os.PathLike,
+    cache_dir: str | os.PathLike | None = None,
     force_download: bool = False,
-    resume_download: Optional[bool] = None,
-    proxies: Optional[dict[str, str]] = None,
-    token: Optional[Union[bool, str]] = None,
-    revision: Optional[str] = None,
+    proxies: dict[str, str] | None = None,
+    token: bool | str | None = None,
+    revision: str | None = None,
     local_files_only: bool = False,
-    repo_type: Optional[str] = None,
-    code_revision: Optional[str] = None,
+    repo_type: str | None = None,
+    code_revision: str | None = None,
     **kwargs,
 ) -> type:
     """
@@ -539,9 +520,6 @@ def get_class_from_dynamic_module(
         force_download (`bool`, *optional*, defaults to `False`):
             Whether or not to force to (re-)download the configuration files and override the cached versions if they
             exist.
-        resume_download:
-            Deprecated and ignored. All downloads are now resumed by default when possible.
-            Will be removed in v5 of Transformers.
         proxies (`dict[str, str]`, *optional*):
             A dictionary of proxy servers to use by protocol or endpoint, e.g., `{'http': 'foo.bar:3128',
             'http://hostname': 'foo.bar:4012'}.` The proxies are used on each request.
@@ -581,16 +559,6 @@ def get_class_from_dynamic_module(
     # module.
     cls = get_class_from_dynamic_module("sgugger/my-bert-model--modeling.MyBertModel", "sgugger/another-bert-model")
     ```"""
-    use_auth_token = kwargs.pop("use_auth_token", None)
-    if use_auth_token is not None:
-        warnings.warn(
-            "The `use_auth_token` argument is deprecated and will be removed in v5 of Transformers. Please use `token` instead.",
-            FutureWarning,
-        )
-        if token is not None:
-            raise ValueError("`token` and `use_auth_token` are both specified. Please set only the argument `token`.")
-        token = use_auth_token
-
     # Catch the name of the repo if it's specified in `class_reference`
     if "--" in class_reference:
         repo_id, class_reference = class_reference.split("--")
@@ -606,7 +574,6 @@ def get_class_from_dynamic_module(
         module_file + ".py",
         cache_dir=cache_dir,
         force_download=force_download,
-        resume_download=resume_download,
         proxies=proxies,
         token=token,
         revision=code_revision,
@@ -616,7 +583,7 @@ def get_class_from_dynamic_module(
     return get_class_in_module(class_name, final_module, force_reload=force_download)
 
 
-def custom_object_save(obj: Any, folder: Union[str, os.PathLike], config: Optional[dict] = None) -> list[str]:
+def custom_object_save(obj: Any, folder: str | os.PathLike, config: dict | None = None) -> list[str]:
     """
     Save the modeling files corresponding to a custom model/configuration/tokenizer etc. in a given folder. Optionally
     adds the proper fields in a config.
@@ -624,7 +591,7 @@ def custom_object_save(obj: Any, folder: Union[str, os.PathLike], config: Option
     Args:
         obj (`Any`): The object for which to save the module files.
         folder (`str` or `os.PathLike`): The folder where to save.
-        config (`PretrainedConfig` or dictionary, `optional`):
+        config (`PreTrainedConfig` or dictionary, `optional`):
             A config in which to register the auto_map corresponding to this custom object.
 
     Returns:
