@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2022 The OpenBMB Team and The HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,31 +14,28 @@
 """PyTorch CPMAnt"""
 
 import math
-from typing import List, Optional, Tuple, Union
 
 import torch
 import torch.nn.functional as F
-import torch.utils.checkpoint
 from torch import nn
 from torch.nn import CrossEntropyLoss
 
+from ... import initialization as init
 from ...activations import ACT2FN
+from ...cache_utils import Cache, DynamicCache
 from ...generation import GenerationMixin
 from ...modeling_outputs import BaseModelOutputWithPast, CausalLMOutputWithPast
 from ...modeling_utils import PreTrainedModel
-from ...utils import add_code_sample_docstrings, add_start_docstrings, add_start_docstrings_to_model_forward, logging
+from ...utils import auto_docstring, logging
 from .configuration_cpmant import CpmAntConfig
 
 
 logger = logging.get_logger(__name__)
 
-_CHECKPOINT_FOR_DOC = "openbmb/cpm-ant-10b"
-_CONFIG_FOR_DOC = "CpmAntConfig"
-
 
 class CpmAntLayerNorm(nn.Module):
     """
-    We use Root Mean Square (RMS) Layer Normalization, please see https://arxiv.org/abs/1910.07467 for details."
+    We use Root Mean Square (RMS) Layer Normalization, please see https://huggingface.co/papers/1910.07467 for details."
     """
 
     def __init__(self, config: CpmAntConfig):
@@ -63,11 +59,12 @@ class CpmAntLayerNorm(nn.Module):
 
 
 class CpmAntAttention(nn.Module):
-    def __init__(self, config: CpmAntConfig):
+    def __init__(self, config: CpmAntConfig, layer_idx=None):
         super().__init__()
         self.dim_model = config.hidden_size
         self.num_heads = config.num_attention_heads
         self.dim_head = config.dim_head
+        self.layer_idx = layer_idx
 
         self.project_q = nn.Linear(self.dim_model, self.num_heads * self.dim_head, bias=False)
         self.project_k = nn.Linear(self.dim_model, self.num_heads * self.dim_head, bias=False)
@@ -88,9 +85,10 @@ class CpmAntAttention(nn.Module):
         hidden_kv: torch.Tensor,
         attention_mask: torch.BoolTensor,
         position_bias: torch.Tensor,
-        output_attentions: Optional[bool] = False,
-        past_key_values: Optional[Tuple[torch.Tensor, torch.Tensor]] = None,
-        use_cache: Optional[bool] = None,
+        output_attentions: bool | None = False,
+        past_key_values: Cache | None = None,
+        use_cache: bool | None = None,
+        cache_position: torch.Tensor | None = None,
     ):
         """
         Args:
@@ -104,7 +102,7 @@ class CpmAntAttention(nn.Module):
                 Provide positional information to self-attention block.
             output_attentions (`bool`, *optional*):
                 Whether or not to return the attentions tensors of all attention layers.
-            past_key_values (`Tuple[torch.Tensor, torch.Tensor]`, *optional*):
+            past_key_values (`Cache`, *optional*):
                 Cached past key and value projection states.
             use_cache (`bool`, *optional*):
                 If set to `True`, `past_key_values` key value states are returned and can be used to speed up decoding
@@ -123,8 +121,7 @@ class CpmAntAttention(nn.Module):
         value = value.view(batch_size, len_k, self.num_heads, self.dim_head).permute(0, 2, 1, 3)
 
         if past_key_values is not None:
-            key = torch.cat([past_key_values[0], key], dim=-2)
-            value = torch.cat([past_key_values[1], value], dim=-2)
+            key, value = past_key_values.update(key, value, self.layer_idx, {"cache_position": cache_position})
             len_k = key.size(-2)
 
         # (batch_size, num_heads, len_q, dim_head) @ (batch_size, num_heads, dim_head, len_k) -> (batch_size, num_heads, len_q, len_k)
@@ -159,18 +156,14 @@ class CpmAntAttention(nn.Module):
 
         score = self.attention_out(score)
 
-        past_key_values = None
-        if use_cache:
-            past_key_values = (key, value)
-
-        return score, attn_weights, past_key_values
+        return score, attn_weights
 
 
 class CpmAntSelfAttentionBlock(nn.Module):
-    def __init__(self, config: CpmAntConfig):
+    def __init__(self, config: CpmAntConfig, layer_idx=None):
         super().__init__()
         self.layernorm_before_attention = CpmAntLayerNorm(config)
-        self.self_attention = CpmAntAttention(config)
+        self.self_attention = CpmAntAttention(config, layer_idx=layer_idx)
         if config.dropout_p:
             self.dropout = torch.nn.Dropout(config.dropout_p)
         else:
@@ -180,10 +173,11 @@ class CpmAntSelfAttentionBlock(nn.Module):
         self,
         hidden_states: torch.Tensor,
         attention_mask: torch.Tensor,
-        position_bias: Optional[torch.Tensor] = None,
-        output_attentions: Optional[bool] = False,
-        past_key_values: Optional[Tuple[torch.Tensor, torch.Tensor]] = None,
-        use_cache: Optional[bool] = None,
+        position_bias: torch.Tensor | None = None,
+        output_attentions: bool | None = False,
+        past_key_values: Cache | None = None,
+        use_cache: bool | None = None,
+        cache_position: torch.Tensor | None = None,
     ):
         """
         Args:
@@ -195,24 +189,29 @@ class CpmAntSelfAttentionBlock(nn.Module):
                 Provide positional information to self-attention block.
             output_attentions (`bool`, *optional*):
                 Whether or not to return the attentions tensors of all attention layers.
-            past_key_values (`Tuple(torch.FloatTensor)`, *optional*):
+            past_key_values (`Cache`, *optional*):
                 Cached past key and value projection states.
             use_cache (`bool`, *optional*):
                 If set to `True`, `past_key_values` key value states are returned and can be used to speed up decoding
                 (see `past_key_values`).
         """
         outputs = self.layernorm_before_attention(hidden_states)
-        outputs = self.self_attention(
-            outputs, outputs, attention_mask, position_bias, output_attentions, past_key_values, use_cache
+        outputs, attn_weights = self.self_attention(
+            outputs,
+            outputs,
+            attention_mask,
+            position_bias,
+            output_attentions,
+            past_key_values,
+            use_cache,
+            cache_position,
         )
 
-        outputs, attn_weights, current_key_value = outputs
-
         if self.dropout is not None:
             outputs = self.dropout(outputs)
         hidden_states = hidden_states + outputs
 
-        return hidden_states, attn_weights, current_key_value
+        return hidden_states, attn_weights
 
 
 class CpmAntDenseGatedACT(nn.Module):
@@ -289,19 +288,20 @@ class CpmAntFFNBlock(nn.Module):
 
 
 class CpmAntTransformerBlock(nn.Module):
-    def __init__(self, config: CpmAntConfig):
+    def __init__(self, config: CpmAntConfig, layer_idx=None):
         super().__init__()
-        self.self_att = CpmAntSelfAttentionBlock(config)
+        self.self_att = CpmAntSelfAttentionBlock(config, layer_idx=layer_idx)
         self.ffn = CpmAntFFNBlock(config)
 
     def forward(
         self,
         hidden_states: torch.Tensor,
         attention_mask: torch.Tensor,
-        position_bias: Optional[torch.Tensor] = None,
-        output_attentions: Optional[bool] = False,
-        past_key_values: Optional[Tuple[torch.Tensor, torch.Tensor]] = None,
-        use_cache: Optional[bool] = None,
+        position_bias: torch.Tensor | None = None,
+        output_attentions: bool | None = False,
+        past_key_values: Cache | None = None,
+        use_cache: bool | None = None,
+        cache_position: torch.Tensor | None = None,
     ):
         """
         Args:
@@ -313,33 +313,31 @@ class CpmAntTransformerBlock(nn.Module):
                 Provides position information to attention mechanism of shape `(num_heads, seq_len, seq_len)`
             output_attentions (`bool`, *optional*):
                 Whether or not to return the attentions tensors of all attention layers.
-            past_key_values (`Tuple[torch.Tensor, torch.Tensor])`, *optional*):
+            past_key_values (`Cache`, *optional*):
                 Cached past key and value projection states
             use_cache (`bool`, *optional*):
                 If set to `True`, `past_key_values` key value states are returned and can be used to speed up decoding
                 (see `past_key_values`).
         """
-        hidden_states = self.self_att(
+        hidden_states, attn_weights = self.self_att(
             hidden_states,
             attention_mask=attention_mask,
             position_bias=position_bias,
             output_attentions=output_attentions,
             past_key_values=past_key_values,
             use_cache=use_cache,
+            cache_position=cache_position,
         )
 
-        hidden_states, attn_weights, current_key_value = hidden_states
-
         hidden_states = self.ffn(hidden_states)
-
-        return hidden_states, attn_weights, current_key_value
+        return hidden_states, attn_weights
 
 
 class CpmAntEncoder(nn.Module):
     def __init__(self, config: CpmAntConfig):
         super().__init__()
         self.num_layers = config.num_hidden_layers
-        self.layers = nn.ModuleList([CpmAntTransformerBlock(config) for ith in range(self.num_layers)])
+        self.layers = nn.ModuleList([CpmAntTransformerBlock(config, layer_idx=i) for i in range(self.num_layers)])
 
         self.output_layernorm = CpmAntLayerNorm(config)
 
@@ -348,10 +346,11 @@ class CpmAntEncoder(nn.Module):
         hidden_states: torch.Tensor,
         attention_mask: torch.Tensor,
         position_bias: torch.Tensor,
-        output_attentions: Optional[bool] = None,
-        output_hidden_states: Optional[bool] = None,
-        past_key_values: Optional[Tuple[torch.Tensor, torch.Tensor]] = None,
-        use_cache: Optional[bool] = None,
+        output_attentions: bool | None = None,
+        output_hidden_states: bool | None = None,
+        past_key_values: Cache | None = None,
+        use_cache: bool | None = None,
+        cache_position: torch.Tensor | None = None,
     ):
         """
         Args:
@@ -365,7 +364,7 @@ class CpmAntEncoder(nn.Module):
                 Whether or not to return the attentions tensors of all attention layers.
             output_hidden_states (`bool`, *optional*):
                 Whether or not to return the hidden states of all layers.
-            past_key_values (`Tuple[torch.Tensor, torch.Tensor])`, *optional*):
+            past_key_values (`Cache`, *optional*):
                 Cached past key and value projection states
             use_cache (`bool`, *optional*):
                 If set to `True`, `past_key_values` key value states are returned and can be used to speed up decoding
@@ -373,7 +372,6 @@ class CpmAntEncoder(nn.Module):
         """
         all_hidden_states = () if output_hidden_states else None
         all_self_attns = () if output_attentions else None
-        current_key_values = () if use_cache else None
 
         for i, layer in enumerate(self.layers):
             if output_hidden_states:
@@ -383,21 +381,19 @@ class CpmAntEncoder(nn.Module):
                 attention_mask,
                 position_bias,
                 output_attentions=output_attentions,
-                past_key_values=past_key_values[i] if past_key_values else None,
+                past_key_values=past_key_values,
                 use_cache=use_cache,
             )
-            hidden_states, attn_weights, current_key_value = layer_outputs
+            hidden_states, attn_weights = layer_outputs
             if output_attentions:
                 all_self_attns += (attn_weights,)
-            if current_key_value is not None:
-                current_key_values = current_key_values + (current_key_value,)
 
         hidden_states = self.output_layernorm(hidden_states)
 
         if output_hidden_states:
             all_hidden_states += (hidden_states,)
 
-        return hidden_states, current_key_values, all_hidden_states, all_self_attns
+        return hidden_states, all_hidden_states, all_self_attns
 
 
 # Copied from transformers.models.bert.modeling_bert.BertIntermediate with Bert->CPMAnt
@@ -454,7 +450,7 @@ class CpmAntSegmentPositionEmbedding(nn.Module):
                 )
             if querylen != query_segment.size(1):
                 raise AssertionError(
-                    f"querylen should be equal to query_segment.size(1), but got {querylen} and {query_segment.szie(1)}!"
+                    f"querylen should be equal to query_segment.size(1), but got {querylen} and {query_segment.size(1)}!"
                 )
 
             key_pos = key_pos.view(batch, -1, keylen)
@@ -495,16 +491,16 @@ class CpmAntSegmentPositionEmbedding(nn.Module):
         relative_position = torch.abs(relative_position)
         max_exact = num_buckets // 2
         is_small = relative_position < max_exact
-        relative_postion_if_large = max_exact + (
+        relative_position_if_large = max_exact + (
             torch.log(relative_position.float() / max_exact)
             / math.log(max_distance / max_exact)
             * (num_buckets - max_exact)
         ).to(torch.int32)
-        relative_postion_if_large = torch.min(
-            relative_postion_if_large,
-            torch.full_like(relative_postion_if_large, num_buckets - 1),
+        relative_position_if_large = torch.min(
+            relative_position_if_large,
+            torch.full_like(relative_position_if_large, num_buckets - 1),
         )
-        relative_buckets += torch.where(is_small, relative_position.to(torch.int32), relative_postion_if_large)
+        relative_buckets += torch.where(is_small, relative_position.to(torch.int32), relative_position_if_large)
         return relative_buckets
 
 
@@ -523,73 +519,22 @@ class CpmAntOutput(nn.Module):
         return hidden_states
 
 
+@auto_docstring
 class CpmAntPreTrainedModel(PreTrainedModel):
-    """
-    An abstract class to handle weights initialization and a simple interface for downloading and loading pretrained
-    models.
-    """
-
-    config_class = CpmAntConfig
+    config: CpmAntConfig
     base_model_prefix = "cpmant"
 
+    @torch.no_grad()
     def _init_weights(self, module):
         """Initialize the weights"""
-        if isinstance(module, nn.Linear):
-            module.weight.data.normal_(mean=0.0, std=self.config.init_std)
-            if module.bias is not None:
-                module.bias.data.zero_()
-        elif isinstance(module, nn.Embedding):
-            module.weight.data.normal_(mean=0.0, std=self.config.init_std)
-            if module.padding_idx is not None:
-                module.weight.data[module.padding_idx].zero_()
-        elif isinstance(module, nn.LayerNorm):
-            module.bias.data.zero_()
-            module.weight.data.fill_(1.0)
-        elif isinstance(module, CpmAntLayerNorm):
-            module.weight.data.fill_(1.0)
+        super()._init_weights(module)
+        if isinstance(module, CpmAntLayerNorm):
+            init.ones_(module.weight)
         elif isinstance(module, CpmAntSegmentPositionEmbedding):
-            module.relative_attention_bias.data.normal_(mean=0.0, std=self.config.init_std)
+            init.normal_(module.relative_attention_bias, mean=0.0, std=self.config.init_std)
 
 
-CPMANT_START_DOCSTRING = r"""
-    This model is a PyTorch [torch.nn.Module](https://pytorch.org/docs/stable/nn.html#torch.nn.Module) sub-class. Use
-    it as a regular PyTorch Module and refer to the PyTorch documentation for all matter related to general usage and
-    behavior.
-
-    Parameters
-        config ([`~CpmAntConfig`]): Model configuration class with all the parameters of the
-            Initializing with a config file does not load the weights associated with the model, only the
-            configuration. Check out the [`~PreTrainedModel.from_pretrained`] method to load the model weights.
-"""
-
-CPMANT_INPUTS_DOCSTRING = r"""
-    Args:
-        input_ids (`torch.Tensor` of shape `(batch_size, seq_len)`):
-            Indices of input sequence tokens in the vocabulary.
-
-            Indices can be obtained using [`CPMAntTokenizer`]. See [`PreTrainedTokenizer.encode`] and
-            [`PreTrainedTokenizer.__call__`] for details.
-
-            [What are input IDs?](../glossary#input-ids)
-        past_key_values (`tuple(tuple(torch.FloatTensor))`, *optional*, returned when `use_cache=True` is passed or when `config.use_cache=True`):
-            Contains pre-computed hidden-states (key and values in the self-attention blocks and in the cross-attention
-            blocks) that can be used (see `past_key_values` input) to speed up sequential decoding.
-        use_cache (`bool`, *optional*):
-            If set to `True`, `past_key_values` key value states are returned and can be used to speed up decoding (see
-            `past_key_values`).
-        output_attentions (`bool`, *optional*):
-            Whether or not to return the attentions tensors of all attention layers.
-        output_hidden_states (`bool`, *optional*):
-            Whether or not to return the hidden states of all layers.
-        return_dict (`bool`, *optional*):
-            Whether or not to return a [`~utils.ModelOutput`] instead of a plain tuple.
-"""
-
-
-@add_start_docstrings(
-    "The bare CPMAnt Model outputting raw hidden-states without any specific head on top.",
-    CPMANT_START_DOCSTRING,
-)
+@auto_docstring
 class CpmAntModel(CpmAntPreTrainedModel):
     def __init__(self, config: CpmAntConfig):
         super().__init__(config)
@@ -628,22 +573,27 @@ class CpmAntModel(CpmAntPreTrainedModel):
         attention_mask = mask_1d.view(batch, seqlen, 1) & mask_1d.view(batch, 1, seqlen) & attention_mask
         return attention_mask
 
-    @add_start_docstrings_to_model_forward(CPMANT_INPUTS_DOCSTRING)
-    @add_code_sample_docstrings(
-        checkpoint=_CHECKPOINT_FOR_DOC,
-        output_type=BaseModelOutputWithPast,
-        config_class=_CONFIG_FOR_DOC,
-    )
+    @auto_docstring
     def forward(
         self,
-        input_ids: Optional[torch.Tensor] = None,
-        output_attentions: Optional[bool] = None,
-        output_hidden_states: Optional[bool] = None,
-        past_key_values: Optional[Tuple[Tuple[torch.Tensor]]] = None,
-        use_cache: Optional[bool] = None,
-        return_dict: Optional[bool] = None,
+        input_ids: torch.Tensor | None = None,
+        output_attentions: bool | None = None,
+        output_hidden_states: bool | None = None,
+        past_key_values: Cache | None = None,
+        use_cache: bool | None = None,
+        return_dict: bool | None = None,
+        cache_position: torch.Tensor | None = None,
         **kwargs,
-    ) -> Union[Tuple[torch.Tensor], BaseModelOutputWithPast]:
+    ) -> tuple[torch.Tensor] | BaseModelOutputWithPast:
+        r"""
+        input_ids (`torch.Tensor` of shape `(batch_size, seq_len)`):
+            Indices of input sequence tokens in the vocabulary.
+
+            Indices can be obtained using [`CPMAntTokenizer`]. See [`PreTrainedTokenizer.encode`] and
+            [`PreTrainedTokenizer.__call__`] for details.
+
+            [What are input IDs?](../glossary#input-ids)
+        """
         output_attentions = output_attentions if output_attentions is not None else self.config.output_attentions
         output_hidden_states = (
             output_hidden_states if output_hidden_states is not None else self.config.output_hidden_states
@@ -675,17 +625,17 @@ class CpmAntModel(CpmAntPreTrainedModel):
         position = torch.arange(seq_length, dtype=dtype, device=device).repeat(batch, 1)
         span = torch.full((batch, seq_length), 0, dtype=dtype, device=device)
 
-        if past_key_values is None:
-            past_length = 0
-            past_key_values = tuple([None] * self.encoder.num_layers)
-            input_ids = input_ids.contiguous()
-            hidden_states = self.input_embedding(input_ids)
-            segment_states = self.segment_embedding(segment)
-            hidden_states = hidden_states + segment_states
-        else:
-            past_length = past_key_values[0][0].size(-2)
-            segment_states = self.segment_embedding(segment)
-            hidden_states = self.input_embedding(input_ids) + segment_states[:, -1:, :]
+        if use_cache and past_key_values is None:
+            past_key_values = DynamicCache(config=self.config)
+
+        past_length = past_key_values.get_seq_length() if past_key_values is not None else 0
+        input_ids = input_ids.contiguous()
+        hidden_states = self.input_embedding(input_ids)
+        segment_states = self.segment_embedding(segment)
+        if past_length != 0:
+            segment_states = segment_states[:, -1:, :]
+
+        hidden_states = hidden_states + segment_states
 
         attention_mask = self._prepare_attention_mask(input_ids, span, context, length)
         position_bias = self.position_bias(position, position, segment, segment)
@@ -694,7 +644,7 @@ class CpmAntModel(CpmAntPreTrainedModel):
         position_bias = position_bias[:, :, past_length:, :]
         hidden_states = hidden_states[:, past_length:, :]
 
-        hidden_states, present_key_values, all_hidden_states, all_attentions = self.encoder(
+        hidden_states, all_hidden_states, all_attentions = self.encoder(
             hidden_states,
             attention_mask,
             position_bias,
@@ -702,6 +652,7 @@ class CpmAntModel(CpmAntPreTrainedModel):
             output_hidden_states,
             past_key_values,
             use_cache,
+            cache_position,
         )
 
         if past_length == 0:
@@ -720,25 +671,24 @@ class CpmAntModel(CpmAntPreTrainedModel):
 
         if not return_dict:
             return tuple(
-                v for v in [hidden_states, present_key_values, all_hidden_states, all_attentions] if v is not None
+                v for v in [hidden_states, past_key_values, all_hidden_states, all_attentions] if v is not None
             )
 
         return BaseModelOutputWithPast(
             last_hidden_state=hidden_states,
-            past_key_values=present_key_values,
+            past_key_values=past_key_values,
             hidden_states=all_hidden_states,
             attentions=all_attentions,
         )
 
 
-@add_start_docstrings(
-    """
+@auto_docstring(
+    custom_intro="""
     The CPMAnt Model with a language modeling head on top (linear layer with weights tied to the input embeddings).
-    """,
-    CPMANT_START_DOCSTRING,
+    """
 )
 class CpmAntForCausalLM(CpmAntPreTrainedModel, GenerationMixin):
-    _tied_weights_keys = ["lm_head.weight"]
+    _tied_weights_keys = {"lm_head.weight": "cpmant.input_embedding.weight"}
 
     def __init__(self, config: CpmAntConfig):
         super().__init__(config)
@@ -750,50 +700,31 @@ class CpmAntForCausalLM(CpmAntPreTrainedModel, GenerationMixin):
         )
         self.post_init()
 
-    @add_start_docstrings_to_model_forward(CPMANT_INPUTS_DOCSTRING)
-    @add_code_sample_docstrings(
-        checkpoint=_CHECKPOINT_FOR_DOC,
-        output_type=CausalLMOutputWithPast,
-        config_class=_CONFIG_FOR_DOC,
-    )
+    @auto_docstring
     def forward(
         self,
-        input_ids: Optional[torch.Tensor] = None,
-        past_key_values: Optional[List[Tuple[torch.Tensor, torch.Tensor]]] = None,
-        use_cache: Optional[bool] = None,
-        output_attentions: Optional[bool] = None,
-        output_hidden_states: Optional[bool] = None,
-        labels: Optional[torch.Tensor] = None,
-        return_dict: Optional[bool] = None,
-        attention_mask: Optional[torch.Tensor] = None,  # dummy parameter for text-generation pipeline
+        input_ids: torch.Tensor | None = None,
+        past_key_values: Cache | None = None,
+        use_cache: bool | None = None,
+        output_attentions: bool | None = None,
+        output_hidden_states: bool | None = None,
+        labels: torch.Tensor | None = None,
+        return_dict: bool | None = None,
+        attention_mask: torch.Tensor | None = None,  # dummy parameter for text-generation pipeline
+        cache_position: torch.Tensor | None = None,
+        logits_to_keep: int | torch.Tensor = 0,
         **kwargs,
-    ) -> Union[Tuple, CausalLMOutputWithPast]:
+    ) -> tuple | CausalLMOutputWithPast:
         r"""
-        Args:
-            input_ids (`torch.Tensor` of shape `(batch_size, seq_len)`):
-                Indices of input sequence tokens in the vocabulary.
+        input_ids (`torch.Tensor` of shape `(batch_size, seq_len)`):
+            Indices of input sequence tokens in the vocabulary.
 
-                Indices can be obtained using [`CPMAntTokenizer`]. See [`PreTrainedTokenizer.encode`] and
-                [`PreTrainedTokenizer.__call__`] for details.
+            Indices can be obtained using [`CPMAntTokenizer`]. See [`PreTrainedTokenizer.encode`] and
+            [`PreTrainedTokenizer.__call__`] for details.
 
-                [What are input IDs?](../glossary#input-ids)
-            past_key_values (`tuple(tuple(torch.FloatTensor))`, *optional*, returned when `use_cache=True` is passed or when `config.use_cache=True`):
-                Contains pre-computed hidden-states (key and values in the self-attention blocks and in the
-                cross-attention blocks) that can be used (see `past_key_values` input) to speed up sequential decoding.
-            use_cache (`bool`, *optional*):
-                If set to `True`, `past_key_values` key value states are returned and can be used to speed up decoding
-                (see `past_key_values`).
-            output_attentions (`bool`, *optional*):
-                Whether or not to return the attentions tensors of all attention layers.
-            output_hidden_states (`bool`, *optional*):
-                Whether or not to return the hidden states of all layers.
-            labels (`torch.Tensor` of shape `(batch_size, sequence_length)`, *optional*):
-                Labels for computing the masked language modeling loss.
-            return_dict (`bool`, *optional*):
-                Whether or not to return a [`~utils.ModelOutput`] instead of a plain tuple.
-            attention_mask (`torch.Tensor` of shape `(batch_size, sequence_length)`, *optional*):
-                CPMAnt will process attention mask automatically, this parameter is a dummy parameter for
-                text-generation pipeline.
+            [What are input IDs?](../glossary#input-ids)
+        labels (`torch.Tensor` of shape `(batch_size, sequence_length)`, *optional*):
+            Labels for computing the masked language modeling loss.
 
         Example:
 
@@ -814,11 +745,18 @@ class CpmAntForCausalLM(CpmAntPreTrainedModel, GenerationMixin):
         return_dict = return_dict if return_dict is not None else self.config.use_return_dict
 
         model_output = self.cpmant(
-            input_ids, output_attentions, output_hidden_states, past_key_values, use_cache, return_dict
+            input_ids,
+            output_attentions,
+            output_hidden_states,
+            past_key_values,
+            use_cache,
+            return_dict,
+            cache_position,
         )
         hidden_states = model_output.last_hidden_state if return_dict else model_output[0]
-
-        logits = self.lm_head(hidden_states)
+        # Only compute necessary logits
+        slice_indices = slice(-logits_to_keep, None) if isinstance(logits_to_keep, int) else logits_to_keep
+        logits = self.lm_head(hidden_states[:, slice_indices, :])
 
         loss = None
         if labels is not None:
@@ -843,27 +781,5 @@ class CpmAntForCausalLM(CpmAntPreTrainedModel, GenerationMixin):
     def set_input_embeddings(self, embeddings):
         self.cpmant.input_embedding = embeddings
 
-    def get_output_embeddings(self):
-        return self.lm_head
 
-    def set_output_embeddings(self, new_embeddings):
-        self.lm_head = new_embeddings
-
-    def prepare_inputs_for_generation(self, input_ids, **kwargs):
-        input_ids = input_ids.int()
-        # save the memory usage of dummy attention mask
-        if "attention_mask" in kwargs:
-            kwargs["attention_mask"] = torch.zeros(1, 1)
-
-        return {
-            "input_ids": input_ids,
-            "use_cache": kwargs["use_cache"],
-            "past_key_values": kwargs.get("past_key_values", None),
-        }
-
-    def _reorder_cache(self, past_key_values, beam_idx):
-        past_key_values = [list(each) if each is not None else each for each in past_key_values]
-        for key_value_layer in past_key_values:
-            key_value_layer[0] = key_value_layer[0][beam_idx]
-            key_value_layer[1] = key_value_layer[1][beam_idx]
-        return past_key_values
+__all__ = ["CpmAntForCausalLM", "CpmAntModel", "CpmAntPreTrainedModel"]
