@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2023 Meta Platforms, Inc. and affiliates, and the HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,30 +14,29 @@
 """EnCodec model configuration"""
 
 import math
-from typing import Optional
 
 import numpy as np
 
-from ...configuration_utils import PretrainedConfig
+from ...configuration_utils import PreTrainedConfig
 from ...utils import logging
 
 
 logger = logging.get_logger(__name__)
 
 
-class EncodecConfig(PretrainedConfig):
+class EncodecConfig(PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration of an [`EncodecModel`]. It is used to instantiate a
     Encodec model according to the specified arguments, defining the model architecture. Instantiating a configuration
     with the defaults will yield a similar configuration to that of the
     [facebook/encodec_24khz](https://huggingface.co/facebook/encodec_24khz) architecture.
 
-    Configuration objects inherit from [`PretrainedConfig`] and can be used to control the model outputs. Read the
-    documentation from [`PretrainedConfig`] for more information.
+    Configuration objects inherit from [`PreTrainedConfig`] and can be used to control the model outputs. Read the
+    documentation from [`PreTrainedConfig`] for more information.
 
     Args:
-        target_bandwidths (`List[float]`, *optional*, defaults to `[1.5, 3.0, 6.0, 12.0, 24.0]`):
-            The range of diffent bandwiths the model can encode audio with.
+        target_bandwidths (`list[float]`, *optional*, defaults to `[1.5, 3.0, 6.0, 12.0, 24.0]`):
+            The range of different bandwidths the model can encode audio with.
         sampling_rate (`int`, *optional*, defaults to 24000):
             The sampling rate at which the audio waveform should be digitalized expressed in hertz (Hz).
         audio_channels (`int`, *optional*, defaults to 1):
@@ -165,7 +163,7 @@ class EncodecConfig(PretrainedConfig):
 
     # This is a property because you might want to change the chunk_length_s on the fly
     @property
-    def chunk_length(self) -> Optional[int]:
+    def chunk_length(self) -> int | None:
         if self.chunk_length_s is None:
             return None
         else:
@@ -173,17 +171,27 @@ class EncodecConfig(PretrainedConfig):
 
     # This is a property because you might want to change the chunk_length_s on the fly
     @property
-    def chunk_stride(self) -> Optional[int]:
+    def chunk_stride(self) -> int | None:
         if self.chunk_length_s is None or self.overlap is None:
             return None
         else:
             return max(1, int((1.0 - self.overlap) * self.chunk_length))
 
+    @property
+    def hop_length(self) -> int:
+        return int(np.prod(self.upsampling_ratios))
+
+    @property
+    def codebook_nbits(self) -> int:
+        return math.ceil(math.log2(self.codebook_size))
+
     @property
     def frame_rate(self) -> int:
-        hop_length = np.prod(self.upsampling_ratios)
-        return math.ceil(self.sampling_rate / hop_length)
+        return math.ceil(self.sampling_rate / self.hop_length)
 
     @property
     def num_quantizers(self) -> int:
-        return int(1000 * self.target_bandwidths[-1] // (self.frame_rate * 10))
+        return int(1000 * self.target_bandwidths[-1] // (self.frame_rate * self.codebook_nbits))
+
+
+__all__ = ["EncodecConfig"]
