@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2024 The HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,15 +15,14 @@
 
 import itertools
 import math
-from typing import Optional, Union
+from typing import Optional
 
 import torch
-from torchvision.transforms.v2 import functional as F
+import torchvision.transforms.v2.functional as tvF
 
 from ...image_processing_utils_fast import (
     BaseImageProcessorFast,
     BatchFeature,
-    DefaultFastImageProcessorKwargs,
     group_images_by_shape,
     reorder_images,
 )
@@ -35,29 +33,12 @@ from ...utils import (
     auto_docstring,
     logging,
 )
+from .image_processing_gemma3 import Gemma3ImageProcessorKwargs
 
 
 logger = logging.get_logger(__name__)
 
 
-class Gemma3FastImageProcessorKwargs(DefaultFastImageProcessorKwargs):
-    """
-    do_pan_and_scan (`bool`, *optional*):
-        Whether to apply `pan_and_scan` to images.
-    pan_and_scan_min_crop_size (`int`, *optional*):
-        Minimum size of each crop in pan and scan.
-    pan_and_scan_max_num_crops (`int`, *optional*):
-        Maximum number of crops per image in pan and scan.
-    pan_and_scan_min_ratio_to_activate (`float`, *optional*):
-        Minimum aspect ratio to activate pan and scan.
-    """
-
-    do_pan_and_scan: Optional[bool]
-    pan_and_scan_min_crop_size: Optional[int]
-    pan_and_scan_max_num_crops: Optional[int]
-    pan_and_scan_min_ratio_to_activate: Optional[float]
-
-
 @auto_docstring
 class Gemma3ImageProcessorFast(BaseImageProcessorFast):
     resample = PILImageResampling.BILINEAR
@@ -73,9 +54,9 @@ class Gemma3ImageProcessorFast(BaseImageProcessorFast):
     pan_and_scan_min_crop_size = None
     pan_and_scan_max_num_crops = None
     pan_and_scan_min_ratio_to_activate = None
-    valid_kwargs = Gemma3FastImageProcessorKwargs
+    valid_kwargs = Gemma3ImageProcessorKwargs
 
-    def __init__(self, **kwargs: Unpack[Gemma3FastImageProcessorKwargs]):
+    def __init__(self, **kwargs: Unpack[Gemma3ImageProcessorKwargs]):
         super().__init__(**kwargs)
 
     def pan_and_scan_batched(
@@ -167,7 +148,7 @@ class Gemma3ImageProcessorFast(BaseImageProcessorFast):
     def preprocess(
         self,
         images: ImageInput,
-        **kwargs: Unpack[Gemma3FastImageProcessorKwargs],
+        **kwargs: Unpack[Gemma3ImageProcessorKwargs],
     ) -> BatchFeature:
         return super().preprocess(images, **kwargs)
 
@@ -176,18 +157,18 @@ class Gemma3ImageProcessorFast(BaseImageProcessorFast):
         images: list[list["torch.Tensor"]],
         do_resize: bool,
         size: SizeDict,
-        do_pan_and_scan: Optional[bool],
-        pan_and_scan_min_crop_size: Optional[int],
-        pan_and_scan_max_num_crops: Optional[int],
-        pan_and_scan_min_ratio_to_activate: Optional[float],
-        interpolation: Optional["F.InterpolationMode"],
+        do_pan_and_scan: bool | None,
+        pan_and_scan_min_crop_size: int | None,
+        pan_and_scan_max_num_crops: int | None,
+        pan_and_scan_min_ratio_to_activate: float | None,
+        interpolation: Optional["tvF.InterpolationMode"],
         do_rescale: bool,
         rescale_factor: float,
         do_normalize: bool,
-        image_mean: Optional[Union[float, list[float]]],
-        image_std: Optional[Union[float, list[float]]],
-        disable_grouping: Optional[bool],
-        return_tensors: Optional[Union[str, TensorType]],
+        image_mean: float | list[float] | None,
+        image_std: float | list[float] | None,
+        disable_grouping: bool | None,
+        return_tensors: str | TensorType | None,
         **kwargs,
     ) -> BatchFeature:
         # Group images by size for batched processing
@@ -249,7 +230,6 @@ class Gemma3ImageProcessorFast(BaseImageProcessorFast):
             processed_images_grouped[shape] = stacked_images
 
         processed_images = reorder_images(processed_images_grouped, grouped_images_index)
-        processed_images = torch.stack(processed_images, dim=0) if return_tensors else processed_images
         return BatchFeature(
             data={"pixel_values": processed_images, "num_crops": num_crops}, tensor_type=return_tensors
         )
