@@ -19,8 +19,10 @@ from ...utils.import_utils import define_import_structure
 
 if TYPE_CHECKING:
     from .configuration_glm4v import *
+    from .image_processing_glm4v import *
     from .modeling_glm4v import *
     from .processing_glm4v import *
+    from .video_processing_glm4v import *
 else:
     import sys
 
