@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2025 The LLAMA4 and HuggingFace Inc. team. All rights reserved.
 #
 #
@@ -14,16 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import warnings
 
-from ...configuration_utils import PretrainedConfig, layer_type_validation
+from ...configuration_utils import PreTrainedConfig, layer_type_validation
+from ...modeling_rope_utils import RopeParameters
 from ...utils import logging
 
 
 logger = logging.get_logger(__name__)
 
 
-class Llama4VisionConfig(PretrainedConfig):
+class Llama4VisionConfig(PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration of a [`Llama4VisionModel`]. It is used to instantiate a
     Llama4 vision model according to the specified arguments, defining the model architecture. Instantiating a configuration
@@ -31,8 +30,8 @@ class Llama4VisionConfig(PretrainedConfig):
 
     e.g. [meta-llama/Llama-4-Scout-17B-16E](https://huggingface.co/meta-llama/Llama-4-Scout-17B-16E)
 
-    Configuration objects inherit from [`PretrainedConfig`] and can be used to control the model outputs. Read the
-    documentation from [`PretrainedConfig`] for more information.
+    Configuration objects inherit from [`PreTrainedConfig`] and can be used to control the model outputs. Read the
+    documentation from [`PreTrainedConfig`] for more information.
 
     Args:
         hidden_size (`int`, *optional*, defaults to 768):
@@ -66,7 +65,8 @@ class Llama4VisionConfig(PretrainedConfig):
         multi_modal_projector_bias (`int`, *optional*, defaults to `False`): TODO
         projector_dropout (`int`, *optional*, defaults to 0.0): TODO
         attention_dropout (`int`, *optional*, defaults to 0.0): TODO
-        rope_theta (`int`, *optional*, defaults to 10000): TODO
+        rope_parameters (`RopeParameters`, *optional*):
+            RoPE Parameters
     """
 
     base_model_tp_plan = {
@@ -83,25 +83,25 @@ class Llama4VisionConfig(PretrainedConfig):
 
     def __init__(
         self,
-        hidden_size: int = 768,
-        hidden_act: str = "gelu",
-        num_hidden_layers: int = 34,
-        num_attention_heads: int = 16,
-        num_channels: int = 3,
-        intermediate_size: int = 5632,
-        vision_output_dim: int = 7680,
-        image_size: int = 448,
-        patch_size: int = 14,
-        norm_eps: float = 1e-5,
-        vision_feature_select_strategy="default",
-        initializer_range: float = 0.02,
-        pixel_shuffle_ratio=0.5,
-        projector_input_dim=4096,
-        projector_output_dim=4096,
-        multi_modal_projector_bias=False,
-        projector_dropout=0.0,
-        attention_dropout=0.0,
-        rope_theta=10000,
+        hidden_size: int | None = 768,
+        hidden_act: str | None = "gelu",
+        num_hidden_layers: int | None = 34,
+        num_attention_heads: int | None = 16,
+        num_channels: int | None = 3,
+        intermediate_size: int | None = 5632,
+        vision_output_dim: int | None = 7680,
+        image_size: int | None = 448,
+        patch_size: int | None = 14,
+        norm_eps: float | None = 1e-5,
+        vision_feature_select_strategy: str | None = "default",
+        initializer_range: float | None = 0.02,
+        pixel_shuffle_ratio: float | None = 0.5,
+        projector_input_dim: int | None = 4096,
+        projector_output_dim: int | None = 4096,
+        multi_modal_projector_bias: bool | None = False,
+        projector_dropout: float | None = 0.0,
+        attention_dropout: float | None = 0.0,
+        rope_parameters: RopeParameters | dict[str, RopeParameters] | None = None,
         **kwargs,
     ):
         self.hidden_size = hidden_size
@@ -122,26 +122,13 @@ class Llama4VisionConfig(PretrainedConfig):
         self.projector_dropout = projector_dropout
         self.attention_dropout = attention_dropout
         self.vision_feature_select_strategy = vision_feature_select_strategy
-        self.rope_theta = rope_theta
 
-        self._vision_feature_layer = kwargs.get("vision_feature_layer", -1)
-
-        @property
-        def vision_feature_layer(self):
-            warnings.warn(
-                "The `vision_feature_layer` attribute is deprecated and will be removed in v4.58.0.",
-                FutureWarning,
-            )
-            return self._vision_feature_layer
-
-        @vision_feature_layer.setter
-        def vision_feature_layer(self, value):
-            self._vision_feature_layer = value
+        self.rope_parameters = rope_parameters
 
         super().__init__(**kwargs)
 
 
-class Llama4TextConfig(PretrainedConfig):
+class Llama4TextConfig(PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration of a [`Llama4TextModel`]. It is used to instantiate a
     Llama4 text model according to the specified arguments, defining the model architecture. Instantiating a configuration
@@ -149,8 +136,8 @@ class Llama4TextConfig(PretrainedConfig):
 
     e.g. [meta-llama/Llama-4-Scout-17B-16E](https://huggingface.co/meta-llama/Llama-4-Scout-17B-16E)
 
-    Configuration objects inherit from [`PretrainedConfig`] and can be used to control the model outputs. Read the
-    documentation from [`PretrainedConfig`] for more information.
+    Configuration objects inherit from [`PreTrainedConfig`] and can be used to control the model outputs. Read the
+    documentation from [`PreTrainedConfig`] for more information.
 
     Args:
         vocab_size (`int`, *optional*, defaults to 202048):
@@ -187,8 +174,6 @@ class Llama4TextConfig(PretrainedConfig):
             The id of the end of sentence token.
         tie_word_embeddings (`bool`, *optional*, defaults to `False`):
             Whether to tie weight embeddings
-        rope_theta (`float`, *optional*, defaults to `500000.0`):
-            The base period of the RoPE embeddings.
         attention_dropout (`int`, *optional*, defaults to 0.0): TODO
         num_experts_per_tok (`int`, *optional*, defaults to 1): TODO
         num_local_experts (`int`, *optional*, defaults to 16): TODO
@@ -198,43 +183,10 @@ class Llama4TextConfig(PretrainedConfig):
         output_router_logits (`int`, *optional*, defaults to `False`): TODO
         router_aux_loss_coef (`int`, *optional*, defaults to 0.001): TODO
         router_jitter_noise (`int`, *optional*, defaults to 0.0): TODO
-        rope_scaling (`Dict`, *optional*):
-            Dictionary containing the scaling configuration for the RoPE embeddings. NOTE: if you apply new rope type
-            and you expect the model to work on longer `max_position_embeddings`, we recommend you to update this value
-            accordingly.
-            Expected contents:
-                `rope_type` (`str`):
-                    The sub-variant of RoPE to use. Can be one of ['default', 'linear', 'dynamic', 'yarn', 'longrope',
-                    'llama3'], with 'default' being the original RoPE implementation.
-                `factor` (`float`, *optional*):
-                    Used with all rope types except 'default'. The scaling factor to apply to the RoPE embeddings. In
-                    most scaling types, a `factor` of x will enable the model to handle sequences of length x *
-                    original maximum pre-trained length.
-                `original_max_position_embeddings` (`int`, *optional*):
-                    Used with 'dynamic', 'longrope' and 'llama3'. The original max position embeddings used during
-                    pretraining.
-                `attention_factor` (`float`, *optional*):
-                    Used with 'yarn' and 'longrope'. The scaling factor to be applied on the attention
-                    computation. If unspecified, it defaults to value recommended by the implementation, using the
-                    `factor` field to infer the suggested value.
-                `beta_fast` (`float`, *optional*):
-                    Only used with 'yarn'. Parameter to set the boundary for extrapolation (only) in the linear
-                    ramp function. If unspecified, it defaults to 32.
-                `beta_slow` (`float`, *optional*):
-                    Only used with 'yarn'. Parameter to set the boundary for interpolation (only) in the linear
-                    ramp function. If unspecified, it defaults to 1.
-                `short_factor` (`list[float]`, *optional*):
-                    Only used with 'longrope'. The scaling factor to be applied to short contexts (<
-                    `original_max_position_embeddings`). Must be a list of numbers with the same length as the hidden
-                    size divided by the number of attention heads divided by 2
-                `long_factor` (`list[float]`, *optional*):
-                    Only used with 'longrope'. The scaling factor to be applied to long contexts (<
-                    `original_max_position_embeddings`). Must be a list of numbers with the same length as the hidden
-                    size divided by the number of attention heads divided by 2
-                `low_freq_factor` (`float`, *optional*):
-                    Only used with 'llama3'. Scaling factor applied to low frequency components of the RoPE
-                `high_freq_factor` (`float`, *optional*):
-                    Only used with 'llama3'. Scaling factor applied to high frequency components of the RoPE
+        rope_parameters (`RopeParameters`, *optional*):
+            Dictionary containing the configuration parameters for the RoPE embeddings. The dictionary should contain
+            a value for `rope_theta` and optionally parameters used for scaling in case you want to use RoPE
+            with longer `max_position_embeddings`.
             <TODO>
             <TODO>
         no_rope_layers (`list[int]`, *optional*):
@@ -259,6 +211,7 @@ class Llama4TextConfig(PretrainedConfig):
 
     model_type = "llama4_text"
     keys_to_ignore_at_inference = ["past_key_values"]
+    default_theta = 500000.0
     base_model_tp_plan = {
         "layers.*.self_attn.q_proj": "colwise",
         "layers.*.self_attn.k_proj": "colwise",
@@ -308,7 +261,6 @@ class Llama4TextConfig(PretrainedConfig):
         bos_token_id=1,
         eos_token_id=2,
         tie_word_embeddings=False,
-        rope_theta=500000,
         attention_dropout=0.0,
         num_experts_per_tok=1,
         num_local_experts=16,
@@ -318,7 +270,7 @@ class Llama4TextConfig(PretrainedConfig):
         output_router_logits=False,
         router_aux_loss_coef=0.001,
         router_jitter_noise=0.0,
-        rope_scaling=None,
+        rope_parameters: RopeParameters | dict[str, RopeParameters] | None = None,
         no_rope_layers=None,
         no_rope_layer_interval=4,
         attention_chunk_size=8192,
@@ -328,13 +280,10 @@ class Llama4TextConfig(PretrainedConfig):
         attn_scale=0.1,
         **kwargs,
     ):
-        super().__init__(
-            pad_token_id=pad_token_id,
-            bos_token_id=bos_token_id,
-            eos_token_id=eos_token_id,
-            tie_word_embeddings=tie_word_embeddings,
-            **kwargs,
-        )
+        self.tie_word_embeddings = tie_word_embeddings
+        self.pad_token_id = pad_token_id
+        self.bos_token_id = bos_token_id
+        self.eos_token_id = eos_token_id
         self.attn_temperature_tuning = attn_temperature_tuning
         self.attn_scale = attn_scale
         self.floor_scale = floor_scale
@@ -345,7 +294,6 @@ class Llama4TextConfig(PretrainedConfig):
         self.intermediate_size_mlp = intermediate_size_mlp
         self.num_hidden_layers = num_hidden_layers
         self.num_attention_heads = num_attention_heads
-        self.rope_scaling = rope_scaling
         self.attention_bias = False
         # for backward compatibility
         if num_key_value_heads is None:
@@ -356,11 +304,9 @@ class Llama4TextConfig(PretrainedConfig):
         self.initializer_range = initializer_range
         self.rms_norm_eps = rms_norm_eps
         self.use_cache = use_cache
-        self.rope_theta = rope_theta
         self.attention_dropout = attention_dropout
         self.head_dim = head_dim if head_dim is not None else self.hidden_size // self.num_attention_heads
         self.use_qk_norm = use_qk_norm
-
         self.num_experts_per_tok = num_experts_per_tok
         self.num_local_experts = num_local_experts
 
@@ -393,8 +339,11 @@ class Llama4TextConfig(PretrainedConfig):
             ]
         layer_type_validation(self.layer_types, self.num_hidden_layers)
 
+        self.rope_parameters = rope_parameters
+        super().__init__(**kwargs)
 
-class Llama4Config(PretrainedConfig):
+
+class Llama4Config(PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration of a [`Llama4Model`]. It is used to instantiate an
     Llama4 model according to the specified arguments, defining the model architecture. Instantiating a configuration
@@ -402,8 +351,8 @@ class Llama4Config(PretrainedConfig):
 
     e.g. [meta-llama/Llama-4-Scout-17B-16E](https://huggingface.co/meta-llama/Llama-4-Scout-17B-16E)
 
-    Configuration objects inherit from [`PretrainedConfig`] and can be used to control the model outputs. Read the
-    documentation from [`PretrainedConfig`] for more information.
+    Configuration objects inherit from [`PreTrainedConfig`] and can be used to control the model outputs. Read the
+    documentation from [`PreTrainedConfig`] for more information.
 
 
     Args:
@@ -473,7 +422,8 @@ class Llama4Config(PretrainedConfig):
         elif isinstance(text_config, Llama4TextConfig):
             self.text_config = text_config
 
-        super().__init__(tie_word_embeddings=tie_word_embeddings, **kwargs)
+        self.tie_word_embeddings = tie_word_embeddings
+        super().__init__(**kwargs)
 
 
 __all__ = ["Llama4Config", "Llama4TextConfig", "Llama4VisionConfig"]
