@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2024 The HuggingFace Inc. team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,7 +14,6 @@
 
 import math
 from functools import lru_cache
-from typing import Dict, List, Optional, Tuple, Union
 
 import numpy as np
 
@@ -33,24 +31,33 @@ from ...image_utils import (
     ImageInput,
     PILImageResampling,
     infer_channel_dimension_format,
-    is_valid_image,
     is_vision_available,
+    make_nested_list_of_images,
     to_numpy_array,
     validate_preprocess_arguments,
 )
+from ...processing_utils import ImagesKwargs
 from ...utils import TensorType, logging
 
 
 if is_vision_available():
-    import PIL
     from PIL import Image
 
 
 logger = logging.get_logger(__name__)
 
 
+class MllamaImageProcessorKwargs(ImagesKwargs, total=False):
+    """
+    max_image_tiles (`int`, *optional*):
+        The maximum number of tiles allowed.
+    """
+
+    max_image_tiles: int
+
+
 @lru_cache(maxsize=10)
-def get_all_supported_aspect_ratios(max_image_tiles: int) -> List[Tuple[int, int]]:
+def get_all_supported_aspect_ratios(max_image_tiles: int) -> list[tuple[int, int]]:
     """
     Computes all allowed aspect ratios for a given maximum number of input tiles.
 
@@ -63,7 +70,7 @@ def get_all_supported_aspect_ratios(max_image_tiles: int) -> List[Tuple[int, int
             The maximum number of tiles allowed.
 
     Returns:
-        `List[Tuple[int, int]]`: A list of tuples, each tuple representing a valid (width, height)
+        `list[tuple[int, int]]`: A list of tuples, each tuple representing a valid (width, height)
         configuration in terms of number of tiles.
 
     Example:
@@ -85,7 +92,7 @@ def get_image_size_fit_to_canvas(
     canvas_height: int,
     canvas_width: int,
     tile_size: int,
-) -> Tuple[int, int]:
+) -> tuple[int, int]:
     """
     Calculates the new size of an image to fit within a canvas while maintaining aspect ratio.
 
@@ -93,7 +100,7 @@ def get_image_size_fit_to_canvas(
     canvas_height and canvas_width, while ensuring that the image dimensions are not smaller than
     tile_size. If the image is larger than the canvas, the returned size will fit within the canvas.
     If the image already fits within the canvas, the size remains unchanged.
-    The aspect ratio of the original image is preserved.
+    The aspect ratio of the original image is preserved as much as possible.
 
     Args:
         image_height (`int`):
@@ -108,7 +115,7 @@ def get_image_size_fit_to_canvas(
             The tile size.
 
     Returns:
-        `Tuple[int, int]`: A tuple containing the new height and width of the image.
+        `tuple[int, int]`: A tuple containing the new height and width of the image.
 
     """
     # Set target image size in between `tile_size` and canvas_size
@@ -120,10 +127,12 @@ def get_image_size_fit_to_canvas(
 
     if scale_w < scale_h:
         new_width = target_width
-        new_height = min(math.floor(image_height * scale_w), target_height)
+        # minimum height is 1 to avoid invalid height of 0
+        new_height = min(math.floor(image_height * scale_w) or 1, target_height)
     else:
         new_height = target_height
-        new_width = min(math.floor(image_width * scale_h), target_width)
+        # minimum width is 1 to avoid invalid width of 0
+        new_width = min(math.floor(image_width * scale_h) or 1, target_width)
 
     return new_height, new_width
 
@@ -134,8 +143,8 @@ def get_optimal_tiled_canvas(
     image_width: int,
     max_image_tiles: int,
     tile_size: int,
-) -> Tuple[int, int]:
-    """
+) -> tuple[int, int]:
+    r"""
     Determines the best canvas based on image and tile size and maximum number of tiles.
 
     First, calculates possible resolutions based on the maximum number of tiles and tile size.
@@ -158,6 +167,74 @@ def get_optimal_tiled_canvas(
     to minimize padding. E.g., the same image can be upscaled to 224x224 and 224x448, but the latter
     has more padding.
 
+    Example of canvases made from tiles:
+
+    To visualize how the image can fit onto different tile grids, let's try fitting an ASCII cat into the tiles.
+
+    Here's an ASCII cat image you want to fit into the tiles:
+
+       /\_/\
+      ( o.o )
+       > ^ <
+
+    If `num_tiles=6`, possible tile grids would look like this:
+
+    **2x3 Canvas (2 tiles wide, 3 tiles tall)**: -> total of 6 tiles
+    +-------+-------+
+    | /\_/\ |   0   |   <- Cat image split across two tiles horizontally
+    +-------+-------+
+    | > ^ < |   0   |   <- Remaining part of the cat occupies the left tile
+    +-------+-------+
+    |( o.o )|   0   |
+    +-------+-------+
+
+    **3x2 Canvas (3 tiles wide, 2 tiles tall)**: -> total of 6 tiles
+    +-------+-------+-------+
+    | /\_/\ |( o.o )|   0   |   <- Cat image occupies the first two tiles, 1 tile remains empty
+    +-------+-------+-------+
+    | > ^ < |   0   |   0   |   <- Remaining part of the cat occupies the left tile
+    +-------+-------+-------+
+
+    **1x6 Canvas (1 tile wide, 6 tiles tall)**: -> total of 6 tiles
+    +-------+
+    | /\_/\ |   <- Top part of the cat
+    +-------+
+    |( o.o )|   <- Middle part of the cat
+    +-------+
+    | > ^ < |   <- Bottom part of the cat
+    +-------+
+    |   0   |
+    +-------+
+    |   0   |
+    +-------+
+    |   0   |
+    +-------+
+
+    Given that the tiles you get depend on the chosen aspect ratio, you have to add
+    embedding in the modeling code to help it know if it got a 3x2 or a 1x6 or a 2x3
+    aspect ratio.
+
+    The function tests these arrangements to find the smallest canvas where the image fits.
+    If multiple canvases fit, it selects the one where the dimensions are closest to the image size.
+
+    In this case the first canvas is the closest to the original image.
+
+    You then feed all of the tiles to the model:
+
+        +-------+-------+-------+-------+-------+-------+
+    -   | /\_/\ |( o.o )| > ^ < |   0   |   0   |   0   |  <- Last canvas
+        +-------+-------+-------+-------+-------+-------+
+
+        +-------+-------+-------+-------+-------+-------+
+    -   | /\_/\ | 0     |( o.o )|   0   | > ^ < |   0   | <- First canvas
+        +-------+-------+-------+-------+-------+-------+
+
+        +-------+-------+-------+-------+-------+-------+
+    -   | /\_/\ |( o.o )|   0   | > ^ < |   0   |   0   | <- second canvas
+        +-------+-------+-------+-------+-------+-------+
+
+    For each tile, you have num_channels (usually RGB so 3), tile_width, tile_height
+
     Args:
         image_height (`int`):
             The height of the image.
@@ -169,7 +246,7 @@ def get_optimal_tiled_canvas(
             The tile size.
 
     Returns:
-        `Tuple[int, int]`: The best canvas resolution [height, width] for the given image.
+        `tuple[int, int]`: The best canvas resolution [height, width] for the given image.
     """
     possible_tile_arrangements = get_all_supported_aspect_ratios(max_image_tiles)
     possible_canvas_sizes = np.array(possible_tile_arrangements) * tile_size
@@ -241,12 +318,12 @@ def split_to_tiles(image: np.ndarray, num_tiles_height: int, num_tiles_width: in
     return np.ascontiguousarray(image)
 
 
-def build_aspect_ratio_mask(aspect_ratios: List[List[Tuple[int, int]]], max_image_tiles: int) -> np.ndarray:
+def build_aspect_ratio_mask(aspect_ratios: list[list[tuple[int, int]]], max_image_tiles: int) -> np.ndarray:
     """
     Builds a mask for the aspect ratios of the images.
 
     Args:
-        aspect_ratios (`List[List[Tuple[int, int]]]`):
+        aspect_ratios (`list[list[tuple[int, int]]]`):
             A list of lists containing aspect ratios for each image in the batch.
             Each aspect ratio is represented as a tuple of (width, height) in terms of number of tiles.
         max_image_tiles (`int`):
@@ -257,7 +334,7 @@ def build_aspect_ratio_mask(aspect_ratios: List[List[Tuple[int, int]]], max_imag
             The mask contains 1s for valid tiles and 0s for padding.
     """
     batch_size = len(aspect_ratios)
-    max_num_images = max([len(row) for row in aspect_ratios])
+    max_num_images = max(len(row) for row in aspect_ratios)
 
     aspect_ratio_mask = np.zeros((batch_size, max_num_images, max_image_tiles), dtype=np.int64)
 
@@ -275,9 +352,9 @@ def build_aspect_ratio_mask(aspect_ratios: List[List[Tuple[int, int]]], max_imag
 
 
 def pack_images(
-    batch_images: List[List[np.ndarray]],
+    batch_images: list[list[np.ndarray]],
     max_image_tiles: int,
-) -> Tuple[np.ndarray, List[List[int]]]:
+) -> tuple[np.ndarray, list[list[int]]]:
     """
     Stack a list of lists of images with variable lengths into a numpy array, applying zero padding as needed.
     Each list in the input represents a batch sample, and each image within a list is expected to be
@@ -285,7 +362,7 @@ def pack_images(
     (batch_size, max_num_images, max_image_tiles, channels, tile_height, tile_width).
 
     Args:
-        batch_images (`List[List[np.ndarray]]`):
+        batch_images (`list[list[np.ndarray]]`):
             A list of lists of image tiles. Each inner list represents
             a batch sample containing multiple images, where each image is pre-split into tiles.
             The shape of each tile array is (num_tiles, channels, tile_height, tile_width).
@@ -293,18 +370,18 @@ def pack_images(
             The maximum number of tiles any image was potantially split.
 
     Returns:
-        `Tuple[np.ndarray, List[List[int]]]`: A tuple containing:
+        `tuple[np.ndarray, list[list[int]]]`: A tuple containing:
             - stacked_images (`np.ndarray`):
                 A numpy array of stacked images with shape
                 (batch_size, max_num_images, max_image_tiles, channels, tile_height, tile_width).
-            - all_num_tiles (`List[List[int]]`):
+            - all_num_tiles (`list[list[int]]`):
                 A list of lists containing the number of tiles
                 for each image in each batch sample.
     """
 
     # Determine output shape
     batch_size = len(batch_images)
-    max_num_images = max([len(images) for images in batch_images])
+    max_num_images = max(len(images) for images in batch_images)
     shapes = [image.shape for images in batch_images for image in images]
     _, channels, tile_height, tile_width = shapes[0]
 
@@ -327,31 +404,7 @@ def pack_images(
     return stacked_images, all_num_tiles
 
 
-def pack_aspect_ratios(aspect_ratios: List[List[Tuple[int, int]]], pad_value: int = 1) -> np.ndarray:
-    """
-    Stack a list of aspect ratios into a numpy array.
-
-    Args:
-        aspect_ratios (`List[List[Tuple[int, int]]]`):
-            A list of aspect ratios.
-        pad_value (`int`, *optional*, defaults to 1):
-            The value to pad the aspect ratios with.
-
-    Returns:
-        `np.ndarray`:
-            The aspect ratios stacked into a numpy array with shape (batch_size, max_num_images, 2).
-    """
-    batch_size = len(aspect_ratios)
-    max_num_images = max([len(row) for row in aspect_ratios])
-
-    aspect_ratios_stacked = np.full((batch_size, max_num_images, 2), pad_value, dtype=np.int64)
-    for i, row in enumerate(aspect_ratios):
-        if len(row) > 0:
-            aspect_ratios_stacked[i, : len(row)] = np.array(row)
-    return aspect_ratios_stacked
-
-
-def convert_aspect_ratios_to_ids(aspect_ratios: List[List[Tuple[int, int]]], max_image_tiles: int) -> np.ndarray:
+def convert_aspect_ratios_to_ids(aspect_ratios: list[list[tuple[int, int]]], max_image_tiles: int) -> np.ndarray:
     """
     Convert aspect ratio tuples to unique ids.
 
@@ -359,7 +412,7 @@ def convert_aspect_ratios_to_ids(aspect_ratios: List[List[Tuple[int, int]]], max
     The aspect ratio ids start from 1, with 1 corresponding to the first supported aspect ratio.
 
     Args:
-        aspect_ratios (`List[List[Tuple[int, int]]]`):
+        aspect_ratios (`list[list[tuple[int, int]]]`):
             A list of aspect ratios for each image in the batch.
         max_image_tiles (`int`):
             The maximum number of tiles any image can be split into.
@@ -372,7 +425,7 @@ def convert_aspect_ratios_to_ids(aspect_ratios: List[List[Tuple[int, int]]], max
     """
 
     batch_size = len(aspect_ratios)
-    max_num_images = max([len(row) for row in aspect_ratios])
+    max_num_images = max(len(row) for row in aspect_ratios)
     supported_aspect_ratios = get_all_supported_aspect_ratios(max_image_tiles)
 
     aspect_ratios_ids = np.zeros((batch_size, max_num_images), dtype=np.int64)
@@ -384,8 +437,8 @@ def convert_aspect_ratios_to_ids(aspect_ratios: List[List[Tuple[int, int]]], max
 
 def to_channel_dimension_format(
     image: np.ndarray,
-    channel_dim: Union[ChannelDimension, str],
-    input_channel_dim: Optional[Union[ChannelDimension, str]] = None,
+    channel_dim: ChannelDimension | str,
+    input_channel_dim: ChannelDimension | str | None = None,
 ) -> np.ndarray:
     """
     Converts `image` to the channel dimension format specified by `channel_dim`.
@@ -403,7 +456,7 @@ def to_channel_dimension_format(
             The image with the channel dimension set to `channel_dim`.
     """
     if not isinstance(image, np.ndarray):
-        raise ValueError(f"Input image must be of type np.ndarray, got {type(image)}")
+        raise TypeError(f"Input image must be of type np.ndarray, got {type(image)}")
 
     if input_channel_dim is None:
         input_channel_dim = infer_channel_dimension_format(image)
@@ -417,7 +470,7 @@ def to_channel_dimension_format(
     elif target_channel_dim == ChannelDimension.LAST:
         image = image.transpose((1, 2, 0))
     else:
-        raise ValueError("Unsupported channel dimension format: {}".format(channel_dim))
+        raise ValueError(f"Unsupported channel dimension format: {channel_dim}")
 
     return image
 
@@ -431,7 +484,7 @@ def convert_to_rgb(image: ImageInput) -> ImageInput:
         image (Image):
             The image to convert.
     """
-    if not isinstance(image, PIL.Image.Image):
+    if not isinstance(image, Image.Image):
         return image
 
     # `image.convert("RGB")` would only work for .jpg images, as it creates a wrong background
@@ -446,43 +499,7 @@ def convert_to_rgb(image: ImageInput) -> ImageInput:
     return alpha_composite
 
 
-# Modified from transformers.models.idefics2.image_processing_idefics2.make_list_of_images
-def make_list_of_images(images: ImageInput) -> List[List[Optional[np.ndarray]]]:
-    """
-    Convert a single image or a list of images to a list of numpy arrays.
-
-    Args:
-        images (`ImageInput`):
-            A single image or a list of images.
-
-    Returns:
-        A list of numpy arrays.
-    """
-    # If it's a single image, convert it to a list of lists
-    if is_valid_image(images):
-        output_images = [[images]]
-    # If it's a list of images, it's a single batch, so convert it to a list of lists
-    elif isinstance(images, (list, tuple)) and is_valid_list_of_images(images):
-        output_images = [images]
-    # If it's a list of batches, it's already in the right format
-    elif (
-        isinstance(images, (list, tuple))
-        and all(isinstance(images_i, (list, tuple)) for images_i in images)
-        and any(is_valid_list_of_images(images_i) for images_i in images)
-    ):
-        output_images = images
-    else:
-        raise ValueError(
-            "Invalid input type. Must be a single image, a list of images, or a list of batches of images."
-        )
-    return output_images
-
-
-def is_valid_list_of_images(images: List):
-    return images and all(is_valid_image(image) for image in images)
-
-
-def _validate_size(size: Dict[str, int]) -> None:
+def _validate_size(size: dict[str, int]) -> None:
     if not ("height" in size and "width" in size):
         raise ValueError(f"Argument `size` must be a dictionary with keys 'height' and 'width'. Got: {size}")
     if size["height"] != size["width"]:
@@ -509,7 +526,7 @@ class MllamaImageProcessor(BaseImageProcessor):
             Only has an effect if the input image is in the PIL format.
         do_resize (`bool`, *optional*, defaults to `True`):
             Whether to resize the image.
-        size (`Dict[str, int]`, *optional*, defaults to `self.size`):
+        size (`dict[str, int]`, *optional*, defaults to `self.size`):
             Size of the image tile. Should be a dictionary containing 'height' and 'width' keys, both with integer values.
             The height and width values should be equal.
         resample (`int`, *optional*, defaults to `Resampling.BILINEAR`):
@@ -521,9 +538,9 @@ class MllamaImageProcessor(BaseImageProcessor):
             Rescale factor to rescale the image by if `do_rescale` is set to `True`.
         do_normalize (`bool`, *optional*, defaults to `True`):
             Whether to normalize the image.
-        image_mean (`float` or `List[float]`, *optional*, defaults to `self.image_mean`):
+        image_mean (`float` or `list[float]`, *optional*, defaults to `self.image_mean`):
             Image mean to use for normalization. Only has an effect if `do_normalize` is set to `True`.
-        image_std (`float` or `List[float]`, *optional*, defaults to `self.image_std`):
+        image_std (`float` or `list[float]`, *optional*, defaults to `self.image_std`):
             Image standard deviation to use for normalization. Only has an effect if `do_normalize` is set to
             `True`.
         do_pad (`bool`, *optional*, defaults to `True`):
@@ -533,18 +550,19 @@ class MllamaImageProcessor(BaseImageProcessor):
     """
 
     model_input_names = ["pixel_values", "num_tiles", "aspect_ratio_ids", "aspect_ratio_mask"]
+    valid_kwargs = MllamaImageProcessorKwargs
 
     def __init__(
         self,
         do_convert_rgb: bool = True,
         do_resize: bool = True,
-        size: Optional[Dict[str, int]] = None,
+        size: dict[str, int] | None = None,
         resample: PILImageResampling = PILImageResampling.BILINEAR,
         do_rescale: bool = True,
         rescale_factor: float = 1 / 255,
         do_normalize: bool = True,
-        image_mean: Optional[Union[float, List[float]]] = None,
-        image_std: Optional[Union[float, List[float]]] = None,
+        image_mean: float | list[float] | None = None,
+        image_std: float | list[float] | None = None,
         do_pad: bool = True,
         max_image_tiles: int = 4,
         **kwargs,
@@ -567,19 +585,19 @@ class MllamaImageProcessor(BaseImageProcessor):
     def preprocess(
         self,
         images: ImageInput,
-        do_convert_rgb: Optional[bool] = None,
-        do_resize: Optional[bool] = None,
-        size: Optional[Dict[str, int]] = None,
-        resample: Optional[PILImageResampling] = None,
-        do_rescale: Optional[bool] = None,
-        rescale_factor: Optional[float] = None,
-        do_normalize: Optional[bool] = None,
-        image_mean: Optional[Union[float, List[float]]] = None,
-        image_std: Optional[Union[float, List[float]]] = None,
-        do_pad: Optional[bool] = None,
-        max_image_tiles: Optional[int] = None,
-        input_data_format: Optional[Union[str, ChannelDimension]] = None,
-        return_tensors: Optional[Union[str, TensorType]] = None,
+        do_convert_rgb: bool | None = None,
+        do_resize: bool | None = None,
+        size: dict[str, int] | None = None,
+        resample: PILImageResampling | None = None,
+        do_rescale: bool | None = None,
+        rescale_factor: float | None = None,
+        do_normalize: bool | None = None,
+        image_mean: float | list[float] | None = None,
+        image_std: float | list[float] | None = None,
+        do_pad: bool | None = None,
+        max_image_tiles: int | None = None,
+        input_data_format: str | ChannelDimension | None = None,
+        return_tensors: str | TensorType | None = None,
     ):
         """
         Preprocess a batch of images.
@@ -591,7 +609,7 @@ class MllamaImageProcessor(BaseImageProcessor):
                 Whether to convert the image to RGB.
             do_resize (`bool`, *optional*, defaults to `self.do_resize`):
                 Whether to resize the image.
-            size (`Dict[str, int]`, *optional*, defaults to `self.size`):
+            size (`dict[str, int]`, *optional*, defaults to `self.size`):
                 Size of the image tile. Should be a dictionary containing 'height' and 'width' keys, both with integer values.
                 The height and width values should be equal.
             resample (`int`, *optional*, defaults to `self.resample`):
@@ -603,9 +621,9 @@ class MllamaImageProcessor(BaseImageProcessor):
                 Rescale factor to rescale the image by if `do_rescale` is set to `True`.
             do_normalize (`bool`, *optional*, defaults to `self.do_normalize`):
                 Whether to normalize the image.
-            image_mean (`float` or `List[float]`, *optional*, defaults to `self.image_mean`):
+            image_mean (`float` or `list[float]`, *optional*, defaults to `self.image_mean`):
                 Image mean to use for normalization. Only has an effect if `do_normalize` is set to `True`.
-            image_std (`float` or `List[float]`, *optional*, defaults to `self.image_std`):
+            image_std (`float` or `list[float]`, *optional*, defaults to `self.image_std`):
                 Image standard deviation to use for normalization. Only has an effect if `do_normalize` is set to
                 `True`.
             do_pad (`bool`, *optional*, defaults to `self.do_pad`):
@@ -621,16 +639,14 @@ class MllamaImageProcessor(BaseImageProcessor):
             return_tensors (`str` or `TensorType`, *optional*):
                 The type of tensors to return. Can be one of:
                 - Unset: Return a list of `np.ndarray`.
-                - `TensorType.TENSORFLOW` or `'tf'`: Return a batch of type `tf.Tensor`.
                 - `TensorType.PYTORCH` or `'pt'`: Return a batch of type `torch.Tensor`.
                 - `TensorType.NUMPY` or `'np'`: Return a batch of type `np.ndarray`.
-                - `TensorType.JAX` or `'jax'`: Return a batch of type `jax.numpy.ndarray`.
 
         Returns:
             `BatchFeature` of the following structure:
                 - **pixel_values** (`TensorType`): The preprocessed pixel values.
                 - **aspect_ratio_ids** (`TensorType`): The aspect ratio ids of the images.
-                - **num_tiles** (`List[List[int]]`): The number of tiles for each image in the batch.
+                - **num_tiles** (`list[list[int]]`): The number of tiles for each image in the batch.
         """
         do_convert_rgb = do_convert_rgb if do_convert_rgb is not None else self.do_convert_rgb
         do_resize = do_resize if do_resize is not None else self.do_resize
@@ -658,13 +674,12 @@ class MllamaImageProcessor(BaseImageProcessor):
         # extra validation
         _validate_mllama_preprocess_arguments(do_resize, size, do_pad, max_image_tiles)
 
-        images_list = make_list_of_images(images)
+        images = self.fetch_images(images)
+        images_list = make_nested_list_of_images(images)
 
         if self.do_convert_rgb:
             images_list = [[convert_to_rgb(image) for image in images] for images in images_list]
 
-        images_list = [[to_numpy_array(image) for image in images] for images in images_list]
-
         batch_images = []
         batch_aspect_ratios = []
 
@@ -675,6 +690,13 @@ class MllamaImageProcessor(BaseImageProcessor):
 
             # iterate over images in a batch sample
             for image in images:
+                # default PIL images to channels_last
+                if input_data_format is None and isinstance(image, Image.Image):
+                    input_data_format = ChannelDimension.LAST
+
+                # convert to numpy array for processing
+                image = to_numpy_array(image)
+
                 # convert images to channels first format for faster processing
                 # LAST is slower for `pad` and not supported by `split_to_tiles`
                 data_format = ChannelDimension.FIRST
@@ -703,7 +725,7 @@ class MllamaImageProcessor(BaseImageProcessor):
                     image = self.rescale(
                         image=image,
                         scale=rescale_factor,
-                        input_data_format=input_data_format,
+                        input_data_format=data_format,
                         data_format=data_format,
                     )
 
@@ -712,7 +734,7 @@ class MllamaImageProcessor(BaseImageProcessor):
                         image=image,
                         mean=image_mean,
                         std=image_std,
-                        input_data_format=input_data_format,
+                        input_data_format=data_format,
                         data_format=data_format,
                     )
 
@@ -732,7 +754,7 @@ class MllamaImageProcessor(BaseImageProcessor):
 
         # images (np.ndarray) with shape (batch_size, max_num_images, max_image_tiles, channels, tile_height, tile_width)
         # aspect_ratio_ids (np.ndarray) with shape (batch_size, max_num_images) - aspect ratio ids for each image, padded to max_num_images with 0
-        # num_tiles (List[List[int]]) with (batch_size, num_images_in_batch) - real number of tiles for each image, not padded
+        # num_tiles (list[list[int]]) with (batch_size, num_images_in_batch) - real number of tiles for each image, not padded
         # aspect_ratio_mask (np.ndarray) with shape (batch_size, max_num_images, max_image_tiles) - number of tiles for each image, padded to max_num_images with 0
         encoded_inputs = BatchFeature(
             data={
@@ -749,10 +771,10 @@ class MllamaImageProcessor(BaseImageProcessor):
     def pad(
         self,
         image: np.ndarray,
-        size: Dict[str, int],
-        aspect_ratio: Tuple[int, int],
-        data_format: Optional[Union[str, ChannelDimension]] = None,
-        input_data_format: Optional[Union[str, ChannelDimension]] = None,
+        size: dict[str, int],
+        aspect_ratio: tuple[int, int],
+        data_format: str | ChannelDimension | None = None,
+        input_data_format: str | ChannelDimension | None = None,
     ) -> np.ndarray:
         """
         Pad an image to the `size` x `aspect_ratio`. For example, if size is {height: 224, width: 224} and aspect ratio is
@@ -761,9 +783,9 @@ class MllamaImageProcessor(BaseImageProcessor):
         Args:
             image (`np.ndarray`):
                 Image to resize.
-            size (`Dict[str, int]`):
+            size (`dict[str, int]`):
                 Size of the output image.
-            aspect_ratio (`Tuple[int, int]`):
+            aspect_ratio (`tuple[int, int]`):
                 The aspect ratio of the image.
             data_format (`str` or `ChannelDimension`, *optional*):
                 The channel dimension format of the image. If not provided, it will be the same as the input image.
@@ -796,12 +818,12 @@ class MllamaImageProcessor(BaseImageProcessor):
     def resize(
         self,
         image: np.ndarray,
-        size: Dict[str, int],
+        size: dict[str, int],
         max_image_tiles: int,
         resample: PILImageResampling = PILImageResampling.BILINEAR,
-        data_format: Optional[Union[str, ChannelDimension]] = None,
-        input_data_format: Optional[Union[str, ChannelDimension]] = None,
-    ) -> Union[np.ndarray, Tuple[int, int]]:
+        data_format: str | ChannelDimension | None = None,
+        input_data_format: str | ChannelDimension | None = None,
+    ) -> np.ndarray | tuple[int, int]:
         """
         Resizes an image to fit within a tiled canvas while maintaining its aspect ratio.
         The optimal canvas size is calculated based on the maximum number of tiles and the tile size.
@@ -813,7 +835,7 @@ class MllamaImageProcessor(BaseImageProcessor):
         Args:
             image (`np.ndarray`):
                 Image to resize.
-            size (`Dict[str, int]`):
+            size (`dict[str, int]`):
                 Size of the output image.
             max_image_tiles (`int`):
                 The maximum number of tiles to split the image into.
@@ -825,7 +847,7 @@ class MllamaImageProcessor(BaseImageProcessor):
                 The channel dimension format of the input image. If not provided, it will be inferred.
 
         Returns:
-            `Union[np.ndarray, Tuple[int, int]]`: The resized image and a tuple containing the number of tiles
+            `Union[np.ndarray, tuple[int, int]]`: The resized image and a tuple containing the number of tiles
             along the height and width dimensions.
         """
 
@@ -860,3 +882,6 @@ class MllamaImageProcessor(BaseImageProcessor):
         )
 
         return image, (num_tiles_height, num_tiles_width)
+
+
+__all__ = ["MllamaImageProcessor"]
