@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2024 Authors: Wenhai Wang, Enze Xie, Xiang Li, Deng-Ping Fan,
 # Kaitao Song, Ding Liang, Tong Lu, Ping Luo, Ling Shao and The HuggingFace Inc. team.
 # All rights reserved.
@@ -16,9 +15,9 @@
 # limitations under the License.
 """Pvt V2 model configuration"""
 
-from typing import Callable, List, Tuple, Union
+from collections.abc import Callable
 
-from ...configuration_utils import PretrainedConfig
+from ...configuration_utils import PreTrainedConfig
 from ...utils import logging
 from ...utils.backbone_utils import BackboneConfigMixin, get_aligned_output_features_output_indices
 
@@ -26,36 +25,36 @@ from ...utils.backbone_utils import BackboneConfigMixin, get_aligned_output_feat
 logger = logging.get_logger(__name__)
 
 
-class PvtV2Config(BackboneConfigMixin, PretrainedConfig):
+class PvtV2Config(BackboneConfigMixin, PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration of a [`PvtV2Model`]. It is used to instantiate a Pvt V2
     model according to the specified arguments, defining the model architecture. Instantiating a configuration with the
     defaults will yield a similar configuration to that of the Pvt V2 B0
     [OpenGVLab/pvt_v2_b0](https://huggingface.co/OpenGVLab/pvt_v2_b0) architecture.
 
-    Configuration objects inherit from [`PretrainedConfig`] and can be used to control the model outputs. Read the
-    documentation from [`PretrainedConfig`] for more information.
+    Configuration objects inherit from [`PreTrainedConfig`] and can be used to control the model outputs. Read the
+    documentation from [`PreTrainedConfig`] for more information.
 
     Args:
-        image_size (`Union[int, Tuple[int, int]]`, *optional*, defaults to 224):
+        image_size (`Union[int, tuple[int, int]]`, *optional*, defaults to 224):
             The input image size. Pass int value for square image, or tuple of (height, width).
         num_channels (`int`, *optional*, defaults to 3):
             The number of input channels.
         num_encoder_blocks (`[int]`, *optional*, defaults to 4):
             The number of encoder blocks (i.e. stages in the Mix Transformer encoder).
-        depths (`List[int]`, *optional*, defaults to `[2, 2, 2, 2]`):
+        depths (`list[int]`, *optional*, defaults to `[2, 2, 2, 2]`):
             The number of layers in each encoder block.
-        sr_ratios (`List[int]`, *optional*, defaults to `[8, 4, 2, 1]`):
+        sr_ratios (`list[int]`, *optional*, defaults to `[8, 4, 2, 1]`):
             Spatial reduction ratios in each encoder block.
-        hidden_sizes (`List[int]`, *optional*, defaults to `[32, 64, 160, 256]`):
+        hidden_sizes (`list[int]`, *optional*, defaults to `[32, 64, 160, 256]`):
             Dimension of each of the encoder blocks.
-        patch_sizes (`List[int]`, *optional*, defaults to `[7, 3, 3, 3]`):
+        patch_sizes (`list[int]`, *optional*, defaults to `[7, 3, 3, 3]`):
             Patch size for overlapping patch embedding before each encoder block.
-        strides (`List[int]`, *optional*, defaults to `[4, 2, 2, 2]`):
+        strides (`list[int]`, *optional*, defaults to `[4, 2, 2, 2]`):
             Stride for overlapping patch embedding before each encoder block.
-        num_attention_heads (`List[int]`, *optional*, defaults to `[1, 2, 5, 8]`):
+        num_attention_heads (`list[int]`, *optional*, defaults to `[1, 2, 5, 8]`):
             Number of attention heads for each attention layer in each block of the Transformer encoder.
-        mlp_ratios (`List[int]`, *optional*, defaults to `[8, 8, 4, 4]`):
+        mlp_ratios (`list[int]`, *optional*, defaults to `[8, 8, 4, 4]`):
             Ratio of the size of the hidden layer compared to the size of the input layer of the Mix FFNs in the
             encoder blocks.
         hidden_act (`str` or `Callable`, *optional*, defaults to `"gelu"`):
@@ -76,11 +75,11 @@ class PvtV2Config(BackboneConfigMixin, PretrainedConfig):
         linear_attention (`bool`, *optional*, defaults to `False`):
             Use linear attention complexity. If set to True, `sr_ratio` is ignored and average pooling is used for
             dimensionality reduction in the attention layers rather than strided convolution.
-        out_features (`List[str]`, *optional*):
+        out_features (`list[str]`, *optional*):
             If used as backbone, list of features to output. Can be any of `"stem"`, `"stage1"`, `"stage2"`, etc.
             (depending on how many stages the model has). If unset and `out_indices` is set, will default to the
             corresponding stages. If unset and `out_indices` is unset, will default to the last stage.
-        out_indices (`List[int]`, *optional*):
+        out_indices (`list[int]`, *optional*):
             If used as backbone, list of indices of features to output. Can be any of 0, 1, 2, etc. (depending on how
             many stages the model has). If unset and `out_features` is set, will default to the corresponding stages.
             If unset and `out_features` is unset, will default to the last stage.
@@ -103,17 +102,17 @@ class PvtV2Config(BackboneConfigMixin, PretrainedConfig):
 
     def __init__(
         self,
-        image_size: Union[int, Tuple[int, int]] = 224,
+        image_size: int | tuple[int, int] = 224,
         num_channels: int = 3,
         num_encoder_blocks: int = 4,
-        depths: List[int] = [2, 2, 2, 2],
-        sr_ratios: List[int] = [8, 4, 2, 1],
-        hidden_sizes: List[int] = [32, 64, 160, 256],
-        patch_sizes: List[int] = [7, 3, 3, 3],
-        strides: List[int] = [4, 2, 2, 2],
-        num_attention_heads: List[int] = [1, 2, 5, 8],
-        mlp_ratios: List[int] = [8, 8, 4, 4],
-        hidden_act: Union[str, Callable] = "gelu",
+        depths: list[int] = [2, 2, 2, 2],
+        sr_ratios: list[int] = [8, 4, 2, 1],
+        hidden_sizes: list[int] = [32, 64, 160, 256],
+        patch_sizes: list[int] = [7, 3, 3, 3],
+        strides: list[int] = [4, 2, 2, 2],
+        num_attention_heads: list[int] = [1, 2, 5, 8],
+        mlp_ratios: list[int] = [8, 8, 4, 4],
+        hidden_act: str | Callable = "gelu",
         hidden_dropout_prob: float = 0.0,
         attention_probs_dropout_prob: float = 0.0,
         initializer_range: float = 0.02,
@@ -151,3 +150,6 @@ class PvtV2Config(BackboneConfigMixin, PretrainedConfig):
         self._out_features, self._out_indices = get_aligned_output_features_output_indices(
             out_features=out_features, out_indices=out_indices, stage_names=self.stage_names
         )
+
+
+__all__ = ["PvtV2Config"]
