@@ -19,9 +19,7 @@ from ...utils.import_utils import define_import_structure
 
 if TYPE_CHECKING:
     from .configuration_roberta_prelayernorm import *
-    from .modeling_flax_roberta_prelayernorm import *
     from .modeling_roberta_prelayernorm import *
-    from .modeling_tf_roberta_prelayernorm import *
 else:
     import sys
 
