@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2021 The Facebook Inc. and The HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,23 +15,16 @@
 
 import json
 import os
-import warnings
 from dataclasses import dataclass
 from itertools import groupby
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Union
 
 import numpy as np
 
-from ...tokenization_utils import PreTrainedTokenizer
-from ...tokenization_utils_base import AddedToken, BatchEncoding
+from ...tokenization_python import PreTrainedTokenizer
+from ...tokenization_utils_base import AddedToken
 from ...utils import (
     ModelOutput,
-    PaddingStrategy,
-    TensorType,
-    add_end_docstrings,
-    is_flax_available,
-    is_tf_available,
-    is_torch_available,
     logging,
     to_py_obj,
 )
@@ -42,12 +34,7 @@ logger = logging.get_logger(__name__)
 
 
 if TYPE_CHECKING:
-    if is_torch_available():
-        import torch
-    if is_tf_available():
-        import tensorflow as tf
-    if is_flax_available():
-        import jax.numpy as jnp  # noqa: F401
+    import torch
 
 
 VOCAB_FILES_NAMES = {
@@ -80,14 +67,13 @@ WAV2VEC2_KWARGS_DOCSTRING = r"""
             return_tensors (`str` or [`~utils.TensorType`], *optional*):
                 If set, will return tensors instead of list of python integers. Acceptable values are:
 
-                - `'tf'`: Return TensorFlow `tf.constant` objects.
                 - `'pt'`: Return PyTorch `torch.Tensor` objects.
                 - `'np'`: Return Numpy `np.ndarray` objects.
             verbose (`bool`, *optional*, defaults to `True`):
                 Whether or not to print more information and warnings.
 """
 
-ListOfDict = List[Dict[str, Union[int, str]]]
+ListOfDict = list[dict[str, int | str]]
 
 
 @dataclass
@@ -98,18 +84,18 @@ class Wav2Vec2CTCTokenizerOutput(ModelOutput):
     Args:
         text (list of `str` or `str`):
             Decoded logits in text from. Usually the speech transcription.
-        char_offsets (list of `List[Dict[str, Union[int, str]]]` or `List[Dict[str, Union[int, str]]]`):
+        char_offsets (list of `list[dict[str, Union[int, str]]]` or `list[dict[str, Union[int, str]]]`):
             Offsets of the decoded characters. In combination with sampling rate and model downsampling rate char
-            offsets can be used to compute time stamps for each charater. Total logit score of the beam associated with
+            offsets can be used to compute time stamps for each character. Total logit score of the beam associated with
             produced text.
-        word_offsets (list of `List[Dict[str, Union[int, str]]]` or `List[Dict[str, Union[int, str]]]`):
+        word_offsets (list of `list[dict[str, Union[int, str]]]` or `list[dict[str, Union[int, str]]]`):
             Offsets of the decoded words. In combination with sampling rate and model downsampling rate word offsets
             can be used to compute time stamps for each word.
     """
 
-    text: Union[List[str], str]
-    char_offsets: Union[List[ListOfDict], ListOfDict] = None
-    word_offsets: Union[List[ListOfDict], ListOfDict] = None
+    text: list[str] | str
+    char_offsets: list[ListOfDict] | ListOfDict = None
+    word_offsets: list[ListOfDict] | ListOfDict = None
 
 
 class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
@@ -186,12 +172,12 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
             word_delimiter_token=word_delimiter_token,
             replace_word_delimiter_char=replace_word_delimiter_char,
             target_lang=target_lang,
+            special_tokens_pattern="none",
             **kwargs,
         )
-
         # make sure that tokens made of several
         # characters are not split at tokenization
-        for token in self.encoder.keys():
+        for token in self.encoder:
             if len(token) > 1:
                 self.add_tokens(AddedToken(token, rstrip=True, lstrip=True, normalized=False))
 
@@ -210,9 +196,14 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         self.encoder = self.vocab[target_lang]
         self.decoder = {v: k for k, v in self.encoder.items()}
 
+        # Remove conflicting entries from _added_tokens_decoder so vocabulary tokens take precedence
+        for token_id in list(self._added_tokens_decoder.keys()):
+            if token_id in self.decoder:
+                del self._added_tokens_decoder[token_id]
+
         # make sure that tokens made of several
         # characters are not split at tokenization
-        for token in self.encoder.keys():
+        for token in self.encoder:
             if len(token) > 1:
                 self.add_tokens(AddedToken(token, rstrip=True, lstrip=True, normalized=False))
 
@@ -227,7 +218,7 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         return str(self._word_delimiter_token)
 
     @property
-    def word_delimiter_token_id(self) -> Optional[int]:
+    def word_delimiter_token_id(self) -> int | None:
         """
         `Optional[int]`: Id of the word_delimiter_token in the vocabulary. Returns `None` if the token has not been
         set.
@@ -248,12 +239,12 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
     def vocab_size(self) -> int:
         return len(self.decoder)
 
-    def get_vocab(self) -> Dict:
+    def get_vocab(self) -> dict:
         vocab = dict(self.encoder)
         vocab.update(self.added_tokens_encoder)
         return vocab
 
-    def _add_tokens(self, new_tokens: Union[List[str], List[AddedToken]], special_tokens: bool = False) -> int:
+    def _add_tokens(self, new_tokens: list[str] | list[AddedToken], special_tokens: bool = False) -> int:
         # Overwritten to never strip!
         to_add = []
         for token in new_tokens:
@@ -282,14 +273,34 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         result = self.decoder.get(index, self.unk_token)
         return result
 
+    def convert_ids_to_tokens(self, ids: int | list[int], skip_special_tokens: bool = False) -> str | list[str]:
+        """Overridden to prioritize vocabulary tokens over added tokens for nested vocabularies."""
+        if isinstance(ids, int):
+            if ids in self.decoder:
+                return self.decoder[ids]
+            return self._added_tokens_decoder[ids].content if ids in self._added_tokens_decoder else self.unk_token
+
+        tokens = []
+        for index in ids:
+            index = int(index)
+            if skip_special_tokens and index in self.all_special_ids:
+                continue
+            if index in self.decoder:
+                tokens.append(self.decoder[index])
+            elif index in self._added_tokens_decoder:
+                tokens.append(self._added_tokens_decoder[index].content)
+            else:
+                tokens.append(self.unk_token)
+        return tokens
+
     def convert_tokens_to_string(
         self,
-        tokens: List[str],
+        tokens: list[str],
         group_tokens: bool = True,
         spaces_between_special_tokens: bool = False,
         output_char_offsets: bool = False,
         output_word_offsets: bool = False,
-    ) -> Dict[str, Union[str, float]]:
+    ) -> dict[str, str | float]:
         """
         Converts a connectionist-temporal-classification (CTC) output tokens into a single string.
         """
@@ -346,9 +357,32 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         return {"text": string, "char_offsets": char_offsets, "word_offsets": word_offsets}
 
     @staticmethod
-    def _compute_offsets(
-        char_repetitions: List[int], chars: List[str], ctc_token: int
-    ) -> List[Dict[str, Union[str, int]]]:
+    def clean_up_tokenization(out_string: str) -> str:
+        """
+        Clean up a list of simple English tokenization artifacts like spaces before punctuations and abbreviated forms.
+
+        Args:
+            out_string (`str`): The text to clean up.
+
+        Returns:
+            `str`: The cleaned-up string.
+        """
+        out_string = (
+            out_string.replace(" .", ".")
+            .replace(" ?", "?")
+            .replace(" !", "!")
+            .replace(" ,", ",")
+            .replace(" ' ", "'")
+            .replace(" n't", "n't")
+            .replace(" 'm", "'m")
+            .replace(" 's", "'s")
+            .replace(" 've", "'ve")
+            .replace(" 're", "'re")
+        )
+        return out_string
+
+    @staticmethod
+    def _compute_offsets(char_repetitions: list[int], chars: list[str], ctc_token: int) -> list[dict[str, str | int]]:
         end_indices = np.asarray(char_repetitions).cumsum()
         start_indices = np.concatenate(([0], end_indices[:-1]))
 
@@ -361,9 +395,7 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         return offsets
 
     @staticmethod
-    def _get_word_offsets(
-        offsets: Dict[str, Union[str, float]], word_delimiter_char: str = " "
-    ) -> Dict[str, Union[str, float]]:
+    def _get_word_offsets(offsets: dict[str, str | float], word_delimiter_char: str = " ") -> dict[str, str | float]:
         word_offsets = []
 
         last_state = "SPACE"
@@ -402,26 +434,25 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
 
     def _decode(
         self,
-        token_ids: List[int],
+        token_ids: list[int],
         skip_special_tokens: bool = False,
-        clean_up_tokenization_spaces: bool = None,
+        clean_up_tokenization_spaces: bool | None = None,
         group_tokens: bool = True,
         spaces_between_special_tokens: bool = False,
-        output_word_offsets: Optional[bool] = False,
-        output_char_offsets: Optional[bool] = False,
+        output_word_offsets: bool | None = False,
+        output_char_offsets: bool | None = False,
     ) -> str:
         """
-        special _decode function is needed for Wav2Vec2Tokenizer because added tokens should be treated exactly the
+        special _decode function is needed because added tokens should be treated exactly the
         same as tokens of the base vocabulary and therefore the function `convert_tokens_to_string` has to be called on
         the whole token list and not individually on added tokens
         """
-        filtered_tokens = self.convert_ids_to_tokens(token_ids, skip_special_tokens=skip_special_tokens)
+        # Don't skip special tokens in convert_ids_to_tokens so we can handle word_delimiter_token specially
+        filtered_tokens = self.convert_ids_to_tokens(token_ids, skip_special_tokens=False)
 
         result = []
         for token in filtered_tokens:
-            if skip_special_tokens and (
-                token in self.all_special_ids or (token != self.pad_token and token in self.all_special_tokens)
-            ):
+            if skip_special_tokens and token in self.all_special_tokens and token != self.word_delimiter_token:
                 continue
             result.append(token)
 
@@ -457,18 +488,18 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
     # because we need docs for `output_char_offsets` here
     def batch_decode(
         self,
-        sequences: Union[List[int], List[List[int]], "np.ndarray", "torch.Tensor", "tf.Tensor"],
+        sequences: Union[list[int], list[list[int]], np.ndarray, "torch.Tensor"],
         skip_special_tokens: bool = False,
-        clean_up_tokenization_spaces: bool = None,
+        clean_up_tokenization_spaces: bool | None = None,
         output_char_offsets: bool = False,
         output_word_offsets: bool = False,
         **kwargs,
-    ) -> List[str]:
+    ) -> list[str]:
         """
         Convert a list of lists of token ids into a list of strings by calling decode.
 
         Args:
-            sequences (`Union[List[int], List[List[int]], np.ndarray, torch.Tensor, tf.Tensor]`):
+            sequences (`Union[list[int], list[list[int]], np.ndarray, torch.Tensor]`):
                 List of tokenized input ids. Can be obtained using the `__call__` method.
             skip_special_tokens (`bool`, *optional*, defaults to `False`):
                 Whether or not to remove special tokens in the decoding.
@@ -502,7 +533,7 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
                 Will be passed to the underlying model specific decode method.
 
         Returns:
-            `List[str]` or [`~models.wav2vec2.tokenization_wav2vec2.Wav2Vec2CTCTokenizerOutput`]: The list of decoded
+            `list[str]` or [`~models.wav2vec2.tokenization_wav2vec2.Wav2Vec2CTCTokenizerOutput`]: The list of decoded
             sentences. Will be a [`~models.wav2vec2.tokenization_wav2vec2.Wav2Vec2CTCTokenizerOutput`] when
             `output_char_offsets == True` or `output_word_offsets == True`.
         """
@@ -527,9 +558,9 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
     # and `output_word_offsets` here
     def decode(
         self,
-        token_ids: Union[int, List[int], "np.ndarray", "torch.Tensor", "tf.Tensor"],
+        token_ids: Union[int, list[int], np.ndarray, "torch.Tensor"],
         skip_special_tokens: bool = False,
-        clean_up_tokenization_spaces: bool = None,
+        clean_up_tokenization_spaces: bool | None = None,
         output_char_offsets: bool = False,
         output_word_offsets: bool = False,
         **kwargs,
@@ -541,7 +572,7 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         Similar to doing `self.convert_tokens_to_string(self.convert_ids_to_tokens(token_ids))`.
 
         Args:
-            token_ids (`Union[int, List[int], np.ndarray, torch.Tensor, tf.Tensor]`):
+            token_ids (`Union[int, list[int], np.ndarray, torch.Tensor]`):
                 List of tokenized input ids. Can be obtained using the `__call__` method.
             skip_special_tokens (`bool`, *optional*, defaults to `False`):
                 Whether or not to remove special tokens in the decoding.
@@ -590,7 +621,7 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         >>> feature_extractor = AutoFeatureExtractor.from_pretrained("facebook/wav2vec2-base-960h")
 
         >>> # load first sample of English common_voice
-        >>> dataset = load_dataset("mozilla-foundation/common_voice_11_0", "en", split="train", streaming=True, trust_remote_code=True)
+        >>> dataset = load_dataset("mozilla-foundation/common_voice_11_0", "en", split="train", streaming=True)
         >>> dataset = dataset.cast_column("audio", datasets.Audio(sampling_rate=16_000))
         >>> dataset_iter = iter(dataset)
         >>> sample = next(dataset_iter)
@@ -630,7 +661,7 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
             **kwargs,
         )
 
-    def save_vocabulary(self, save_directory: str, filename_prefix: Optional[str] = None) -> Tuple[str]:
+    def save_vocabulary(self, save_directory: str, filename_prefix: str | None = None) -> tuple[str]:
         if not os.path.isdir(save_directory):
             logger.error(f"Vocabulary path ({save_directory}) should be a directory")
             return
@@ -644,281 +675,4 @@ class Wav2Vec2CTCTokenizer(PreTrainedTokenizer):
         return (vocab_file,)
 
 
-class Wav2Vec2Tokenizer(PreTrainedTokenizer):
-    """
-    Constructs a Wav2Vec2 tokenizer.
-
-    This tokenizer inherits from [`PreTrainedTokenizer`] which contains some of the main methods. Users should refer to
-    the superclass for more information regarding such methods.
-
-    Args:
-        vocab_file (`str`):
-            File containing the vocabulary.
-        bos_token (`str`, *optional*, defaults to `"<s>"`):
-            The beginning of sentence token.
-        eos_token (`str`, *optional*, defaults to `"</s>"`):
-            The end of sentence token.
-        unk_token (`str`, *optional*, defaults to `"<unk>"`):
-            The unknown token. A token that is not in the vocabulary cannot be converted to an ID and is set to be this
-            token instead.
-        pad_token (`str`, *optional*, defaults to `"<pad>"`):
-            The token used for padding, for example when batching sequences of different lengths.
-        word_delimiter_token (`str`, *optional*, defaults to `"|"`):
-            The token used for defining the end of a word.
-        do_lower_case (`bool`, *optional*, defaults to `False`):
-            Whether or not to lowercase the output when decoding.
-        do_normalize (`bool`, *optional*, defaults to `False`):
-            Whether or not to zero-mean unit-variance normalize the input. Normalizing can help to significantly
-            improve the performance for some models, *e.g.*,
-            [wav2vec2-lv60](https://huggingface.co/models?search=lv60).
-        return_attention_mask (`bool`, *optional*, defaults to `False`):
-            Whether or not [`~Wav2Vec2Tokenizer.__call__`] should return `attention_mask`.
-
-            <Tip>
-
-            Wav2Vec2 models that have set `config.feat_extract_norm == "group"`, such as
-            [wav2vec2-base](https://huggingface.co/facebook/wav2vec2-base-960h), have **not** been trained using
-            `attention_mask`. For such models, `input_values` should simply be padded with 0 and no `attention_mask`
-            should be passed.
-
-            For Wav2Vec2 models that have set `config.feat_extract_norm == "layer"`, such as
-            [wav2vec2-lv60](https://huggingface.co/facebook/wav2vec2-large-960h-lv60-self), `attention_mask` should be
-            passed for batched inference.
-
-            </Tip>
-
-        **kwargs
-            Additional keyword arguments passed along to [`PreTrainedTokenizer`]
-    """
-
-    vocab_files_names = VOCAB_FILES_NAMES
-    pretrained_vocab_files_map = {
-        "vocab_file": {
-            "facebook/wav2vec2-base-960h": "https://huggingface.co/facebook/wav2vec2-base-960h/resolve/main/vocab.json"
-        },
-        "tokenizer_config_file": {
-            "facebook/wav2vec2-base-960h": (
-                "https://huggingface.co/facebook/wav2vec2-base-960h/resolve/main/tokenizer.json"
-            ),
-        },
-    }
-    model_input_names = ["input_values", "attention_mask"]
-
-    def __init__(
-        self,
-        vocab_file,
-        bos_token="<s>",
-        eos_token="</s>",
-        unk_token="<unk>",
-        pad_token="<pad>",
-        word_delimiter_token="|",
-        do_lower_case=False,
-        do_normalize=False,
-        return_attention_mask=False,
-        **kwargs,
-    ):
-        warnings.warn(
-            "The class `Wav2Vec2Tokenizer` is deprecated and will be removed in version 5 of Transformers. Please use"
-            " `Wav2Vec2Processor` or `Wav2Vec2CTCTokenizer` instead.",
-            FutureWarning,
-        )
-
-        self._word_delimiter_token = word_delimiter_token
-
-        self.do_lower_case = do_lower_case
-        self.return_attention_mask = return_attention_mask
-        self.do_normalize = do_normalize
-
-        with open(vocab_file, encoding="utf-8") as vocab_handle:
-            self.encoder = json.load(vocab_handle)
-
-        self.decoder = {v: k for k, v in self.encoder.items()}
-
-        super().__init__(
-            unk_token=unk_token,
-            bos_token=bos_token,
-            eos_token=eos_token,
-            pad_token=pad_token,
-            do_lower_case=do_lower_case,
-            do_normalize=do_normalize,
-            return_attention_mask=return_attention_mask,
-            word_delimiter_token=word_delimiter_token,
-            **kwargs,
-        )
-
-    @property
-    def word_delimiter_token(self) -> str:
-        """
-        `str`: Padding token. Log an error if used while not having been set.
-        """
-        if self._word_delimiter_token is None and self.verbose:
-            logger.error("Using word_delimiter_token, but it is not set yet.")
-            return None
-        return str(self._word_delimiter_token)
-
-    @property
-    def word_delimiter_token_id(self) -> Optional[int]:
-        """
-        `Optional[int]`: Id of the word_delimiter_token in the vocabulary. Returns `None` if the token has not been
-        set.
-        """
-        if self._word_delimiter_token is None:
-            return None
-        return self.convert_tokens_to_ids(self.word_delimiter_token)
-
-    @word_delimiter_token.setter
-    def word_delimiter_token(self, value):
-        self._word_delimiter_token = value
-
-    @word_delimiter_token_id.setter
-    def word_delimiter_token_id(self, value):
-        self._word_delimiter_token = self.convert_tokens_to_ids(value)
-
-    @add_end_docstrings(WAV2VEC2_KWARGS_DOCSTRING)
-    def __call__(
-        self,
-        raw_speech: Union[np.ndarray, List[float], List[np.ndarray], List[List[float]]],
-        padding: Union[bool, str, PaddingStrategy] = False,
-        max_length: Optional[int] = None,
-        pad_to_multiple_of: Optional[int] = None,
-        padding_side: Optional[bool] = None,
-        return_tensors: Optional[Union[str, TensorType]] = None,
-        verbose: bool = True,
-        **kwargs,
-    ) -> BatchEncoding:
-        """
-        Main method to tokenize and prepare for the model one or several sequence(s) or one or several pair(s) of
-        sequences.
-
-        Args:
-            raw_speech (`np.ndarray`, `List[float]`, `List[np.ndarray]`, `List[List[float]]`):
-                The sequence or batch of sequences to be padded. Each sequence can be a numpy array, a list of float
-                values, a list of numpy array or a list of list of float values. Must be mono channel audio, not
-                stereo, i.e. single float per timestep.
-
-            padding_side (`str`, *optional*):
-                The side on which the model should have padding applied. Should be selected between ['right', 'left'].
-                Default value is picked from the class attribute of the same name.
-        """
-
-        is_batched_numpy = isinstance(raw_speech, np.ndarray) and len(raw_speech.shape) > 1
-        if is_batched_numpy and len(raw_speech.shape) > 2:
-            raise ValueError(f"Only mono-channel audio is supported for input to {self}")
-        is_batched = is_batched_numpy or (
-            isinstance(raw_speech, (list, tuple)) and (isinstance(raw_speech[0], (np.ndarray, tuple, list)))
-        )
-
-        # make sure input is in list format
-        if is_batched and not isinstance(raw_speech[0], np.ndarray):
-            raw_speech = [np.asarray(speech) for speech in raw_speech]
-        elif not is_batched and not isinstance(raw_speech, np.ndarray):
-            raw_speech = np.asarray(raw_speech)
-
-        # always return batch
-        if not is_batched:
-            raw_speech = [raw_speech]
-
-        # zero-mean and unit-variance normalization
-        if self.do_normalize:
-            raw_speech = [(x - np.mean(x)) / np.sqrt(np.var(x) + 1e-5) for x in raw_speech]
-
-        # convert into correct format for padding
-        encoded_inputs = BatchEncoding({"input_values": raw_speech})
-
-        padded_inputs = self.pad(
-            encoded_inputs,
-            padding=padding,
-            max_length=max_length,
-            pad_to_multiple_of=pad_to_multiple_of,
-            padding_side=padding_side,
-            return_attention_mask=self.return_attention_mask,
-            return_tensors=return_tensors,
-            verbose=verbose,
-        )
-
-        return padded_inputs
-
-    @property
-    def vocab_size(self) -> int:
-        return len(self.decoder)
-
-    def get_vocab(self) -> Dict:
-        return dict(self.encoder, **self.added_tokens_encoder)
-
-    def _convert_token_to_id(self, token: str) -> int:
-        """Converts a token (str) in an index (integer) using the vocab."""
-        return self.encoder.get(token, self.encoder.get(self.unk_token))
-
-    def _convert_id_to_token(self, index: int) -> str:
-        """Converts an index (integer) in a token (str) using the vocab."""
-        result = self.decoder.get(index, self.unk_token)
-        return result
-
-    def convert_tokens_to_string(self, tokens: List[str]) -> str:
-        """
-        Converts a connectionist-temporal-classification (CTC) output tokens into a single string.
-        """
-        # group same tokens into non-repeating tokens in CTC style decoding
-        grouped_tokens = [token_group[0] for token_group in groupby(tokens)]
-
-        # filter self.pad_token which is used as CTC-blank token
-        filtered_tokens = list(filter(lambda token: token != self.pad_token, grouped_tokens))
-
-        # replace delimiter token
-        string = "".join([" " if token == self.word_delimiter_token else token for token in filtered_tokens]).strip()
-
-        if self.do_lower_case:
-            string = string.lower()
-
-        return string
-
-    def _decode(
-        self,
-        token_ids: List[int],
-        skip_special_tokens: bool = False,
-        clean_up_tokenization_spaces: bool = None,
-        **kwargs,
-    ) -> str:
-        """
-        special _decode function is needed for Wav2Vec2Tokenizer because added tokens should be treated exactly the
-        same as tokens of the base vocabulary and therefore the function `convert_tokens_to_string` has to be called on
-        the whole token list and not individually on added tokens
-        """
-        filtered_tokens = self.convert_ids_to_tokens(token_ids, skip_special_tokens=skip_special_tokens)
-
-        result = []
-        for token in filtered_tokens:
-            if skip_special_tokens and (
-                token in self.all_special_ids or (token != self.pad_token and token in self.all_special_tokens)
-            ):
-                continue
-            result.append(token)
-
-        text = self.convert_tokens_to_string(result)
-
-        clean_up_tokenization_spaces = (
-            clean_up_tokenization_spaces
-            if clean_up_tokenization_spaces is not None
-            else self.clean_up_tokenization_spaces
-        )
-        if clean_up_tokenization_spaces:
-            clean_text = self.clean_up_tokenization(text)
-            return clean_text
-        else:
-            return text
-
-    def save_vocabulary(self, save_directory: str, filename_prefix: Optional[str] = None) -> Tuple[str]:
-        if not os.path.isdir(save_directory):
-            logger.error(f"Vocabulary path ({save_directory}) should be a directory")
-            return
-        vocab_file = os.path.join(
-            save_directory, (filename_prefix + "-" if filename_prefix else "") + VOCAB_FILES_NAMES["vocab_file"]
-        )
-
-        with open(vocab_file, "w", encoding="utf-8") as f:
-            f.write(json.dumps(self.encoder, indent=2, sort_keys=True, ensure_ascii=False) + "\n")
-
-        return (vocab_file,)
-
-
-__all__ = ["Wav2Vec2CTCTokenizer", "Wav2Vec2Tokenizer"]
+__all__ = ["Wav2Vec2CTCTokenizer"]
