@@ -19,8 +19,6 @@ from ...utils.import_utils import define_import_structure
 
 if TYPE_CHECKING:
     from .configuration_xlm_roberta import *
-    from .modeling_flax_xlm_roberta import *
-    from .modeling_tf_xlm_roberta import *
     from .modeling_xlm_roberta import *
     from .tokenization_xlm_roberta import *
     from .tokenization_xlm_roberta_fast import *
