@@ -1,6 +1,6 @@
 from typing import Optional
 
-import requests
+import httpx
 from huggingface_hub import Discussion, HfApi, get_repo_discussions
 
 from .utils import cached_file, http_user_agent, logging
@@ -44,10 +44,10 @@ def spawn_conversion(token: str, private: bool, model_id: str):
 
     data = {"data": [model_id, private, token]}
 
-    result = requests.post(sse_url, stream=True, json=data).json()
+    result = httpx.post(sse_url, follow_redirects=True, json=data).json()
     event_id = result["event_id"]
 
-    with requests.get(f"{sse_url}/{event_id}", stream=True) as sse_connection:
+    with httpx.stream("GET", f"{sse_url}/{event_id}") as sse_connection:
         try:
             logger.debug("Spawning safetensors automatic conversion.")
             start(sse_connection)
@@ -72,13 +72,24 @@ def get_conversion_pr_reference(api: HfApi, model_id: str, **kwargs):
         pr = previous_pr(api, model_id, pr_title, token=token)
     else:
         logger.info("Safetensors PR exists")
+    if pr is None:
+        raise OSError(
+            "Could not create safetensors conversion PR. The repo does not appear to have a file named pytorch_model.bin or model.safetensors."
+            "If you are loading with variant, use `use_safetensors=False` to load the original model."
+        )
 
     sha = f"refs/pr/{pr.num}"
 
     return sha
 
 
-def auto_conversion(pretrained_model_name_or_path: str, ignore_errors_during_conversion=False, **cached_file_kwargs):
+def auto_conversion(
+    pretrained_model_name_or_path: str,
+    ignore_errors_during_conversion: bool = False,
+    safe_weights_name: str = "model.safetensors",
+    safe_weights_index_name: str = "model.safetensors.index.json",
+    **cached_file_kwargs,
+):
     try:
         api = HfApi(token=cached_file_kwargs.get("token"), headers={"user-agent": http_user_agent()})
         sha = get_conversion_pr_reference(api, pretrained_model_name_or_path, **cached_file_kwargs)
@@ -92,11 +103,11 @@ def auto_conversion(pretrained_model_name_or_path: str, ignore_errors_during_con
         # description.
         sharded = api.file_exists(
             pretrained_model_name_or_path,
-            "model.safetensors.index.json",
+            safe_weights_index_name,
             revision=sha,
             token=cached_file_kwargs.get("token"),
         )
-        filename = "model.safetensors.index.json" if sharded else "model.safetensors"
+        filename = safe_weights_index_name if sharded else safe_weights_name
 
         resolved_archive_file = cached_file(pretrained_model_name_or_path, filename, **cached_file_kwargs)
         return resolved_archive_file, sha, sharded
