@@ -19,19 +19,24 @@ import copy
 import functools
 import gc
 import inspect
+import json
 import os
 import random
 import re
 import threading
 import time
-from typing import Any, Callable, NamedTuple, Optional, Union
+from collections.abc import Callable
+from functools import partial
+from typing import Any, NamedTuple
 
 import numpy as np
 
 from .utils import (
+    SAFE_WEIGHTS_INDEX_NAME,
+    WEIGHTS_INDEX_NAME,
     ExplicitEnum,
+    check_torch_load_is_safe,
     is_psutil_available,
-    is_tf_available,
     is_torch_available,
     is_torch_cuda_available,
     is_torch_hpu_available,
@@ -47,6 +52,7 @@ from .utils import (
 
 if is_torch_available():
     import torch
+    from safetensors.torch import load_file as safe_load_file
 
 
 def seed_worker(worker_id: int, num_workers: int, rank: int):
@@ -61,8 +67,7 @@ def seed_worker(worker_id: int, num_workers: int, rank: int):
 def enable_full_determinism(seed: int, warn_only: bool = False):
     """
     Helper function for reproducible behavior during distributed training. See
-    - https://pytorch.org/docs/stable/notes/randomness.html for pytorch
-    - https://www.tensorflow.org/api_docs/python/tf/config/experimental/enable_op_determinism for tensorflow
+    https://pytorch.org/docs/stable/notes/randomness.html for pytorch
     """
     # set seed first
     set_seed(seed)
@@ -84,15 +89,10 @@ def enable_full_determinism(seed: int, warn_only: bool = False):
         torch.backends.cudnn.deterministic = True
         torch.backends.cudnn.benchmark = False
 
-    if is_tf_available():
-        import tensorflow as tf
-
-        tf.config.experimental.enable_op_determinism()
-
 
 def set_seed(seed: int, deterministic: bool = False):
     """
-    Helper function for reproducible behavior to set the seed in `random`, `numpy`, `torch` and/or `tf` (if installed).
+    Helper function for reproducible behavior to set the seed in `random`, `numpy`, `torch` (if installed).
 
     Args:
         seed (`int`):
@@ -118,12 +118,6 @@ def set_seed(seed: int, deterministic: bool = False):
         torch.hpu.manual_seed_all(seed)
     if is_torch_xpu_available():
         torch.xpu.manual_seed_all(seed)
-    if is_tf_available():
-        import tensorflow as tf
-
-        tf.random.set_seed(seed)
-        if deterministic:
-            tf.config.experimental.enable_op_determinism()
 
 
 def neftune_post_forward_hook(module, input, output):
@@ -165,10 +159,10 @@ class EvalPrediction:
 
     def __init__(
         self,
-        predictions: Union[np.ndarray, tuple[np.ndarray]],
-        label_ids: Union[np.ndarray, tuple[np.ndarray]],
-        inputs: Optional[Union[np.ndarray, tuple[np.ndarray]]] = None,
-        losses: Optional[Union[np.ndarray, tuple[np.ndarray]]] = None,
+        predictions: np.ndarray | tuple[np.ndarray],
+        label_ids: np.ndarray | tuple[np.ndarray],
+        inputs: np.ndarray | tuple[np.ndarray] | None = None,
+        losses: np.ndarray | tuple[np.ndarray] | None = None,
     ):
         self.predictions = predictions
         self.label_ids = label_ids
@@ -190,16 +184,16 @@ class EvalPrediction:
 
 
 class EvalLoopOutput(NamedTuple):
-    predictions: Union[np.ndarray, tuple[np.ndarray]]
-    label_ids: Optional[Union[np.ndarray, tuple[np.ndarray]]]
-    metrics: Optional[dict[str, float]]
-    num_samples: Optional[int]
+    predictions: np.ndarray | tuple[np.ndarray]
+    label_ids: np.ndarray | tuple[np.ndarray] | None
+    metrics: dict[str, float] | None
+    num_samples: int | None
 
 
 class PredictionOutput(NamedTuple):
-    predictions: Union[np.ndarray, tuple[np.ndarray]]
-    label_ids: Optional[Union[np.ndarray, tuple[np.ndarray]]]
-    metrics: Optional[dict[str, float]]
+    predictions: np.ndarray | tuple[np.ndarray]
+    label_ids: np.ndarray | tuple[np.ndarray] | None
+    metrics: dict[str, float] | None
 
 
 class TrainOutput(NamedTuple):
@@ -237,12 +231,6 @@ class SaveStrategy(ExplicitEnum):
     BEST = "best"
 
 
-class EvaluationStrategy(ExplicitEnum):
-    NO = "no"
-    STEPS = "steps"
-    EPOCH = "epoch"
-
-
 class HubStrategy(ExplicitEnum):
     END = "end"
     EVERY_SAVE = "every_save"
@@ -267,9 +255,9 @@ class BestRun(NamedTuple):
     """
 
     run_id: str
-    objective: Union[float, list[float]]
+    objective: float | list[float]
     hyperparameters: dict[str, Any]
-    run_summary: Optional[Any] = None
+    run_summary: Any | None = None
 
 
 def default_compute_objective(metrics: dict[str, float]) -> float:
@@ -287,9 +275,7 @@ def default_compute_objective(metrics: dict[str, float]) -> float:
     loss = metrics.pop("eval_loss", None)
     _ = metrics.pop("epoch", None)
     # Remove speed metrics
-    speed_metrics = [
-        m for m in metrics if m.endswith("_runtime") or m.endswith("_per_second") or m.endswith("_compilation_time")
-    ]
+    speed_metrics = [m for m in metrics if m.endswith("_runtime") or m.endswith("_per_second")]
     for sm in speed_metrics:
         _ = metrics.pop(sm, None)
     return loss if len(metrics) == 0 else sum(metrics.values())
@@ -321,19 +307,6 @@ def default_hp_space_ray(trial) -> dict[str, Any]:
     }
 
 
-def default_hp_space_sigopt(trial):
-    return [
-        {"bounds": {"min": 1e-6, "max": 1e-4}, "name": "learning_rate", "type": "double", "transformation": "log"},
-        {"bounds": {"min": 1, "max": 6}, "name": "num_train_epochs", "type": "int"},
-        {"bounds": {"min": 1, "max": 40}, "name": "seed", "type": "int"},
-        {
-            "categorical_values": ["4", "8", "16", "32", "64"],
-            "name": "per_device_train_batch_size",
-            "type": "categorical",
-        },
-    ]
-
-
 def default_hp_space_wandb(trial) -> dict[str, Any]:
     from .integrations import is_wandb_available
 
@@ -355,7 +328,6 @@ def default_hp_space_wandb(trial) -> dict[str, Any]:
 class HPSearchBackend(ExplicitEnum):
     OPTUNA = "optuna"
     RAY = "ray"
-    SIGOPT = "sigopt"
     WANDB = "wandb"
 
 
@@ -465,8 +437,6 @@ class TrainerMemoryTracker:
     self._memory_tracker.stop_and_update_metrics(metrics)
     ```
 
-    At the moment GPU tracking is only for `pytorch`, but can be extended to support `tensorflow`.
-
     To understand this class' intricacies please read the documentation of [`~Trainer.log_metrics`].
     """
 
@@ -793,7 +763,7 @@ def number_of_arguments(func):
 
 
 def find_executable_batch_size(
-    function: Optional[Callable] = None, starting_batch_size: int = 128, auto_find_batch_size: bool = False
+    function: Callable | None = None, starting_batch_size: int = 128, auto_find_batch_size: bool = False
 ):
     """
     Args:
@@ -841,8 +811,8 @@ class RemoveColumnsCollator:
         data_collator,
         signature_columns,
         logger=None,
-        model_name: Optional[str] = None,
-        description: Optional[str] = None,
+        model_name: str | None = None,
+        description: str | None = None,
     ):
         self.data_collator = data_collator
         self.signature_columns = signature_columns
@@ -909,3 +879,79 @@ def check_target_module_exists(optim_target_modules, key: str, return_is_regex:
         return target_module_found, is_regex
 
     return target_module_found
+
+
+def load_sharded_checkpoint(model, folder, strict=True, prefer_safe=True):
+    """
+    This is the same as
+    [`torch.nn.Module.load_state_dict`](https://pytorch.org/docs/stable/generated/torch.nn.Module.html?highlight=load_state_dict#torch.nn.Module.load_state_dict)
+    but for a sharded checkpoint.
+
+    This load is performed efficiently: each checkpoint shard is loaded one by one in RAM and deleted after being
+    loaded in the model.
+
+    Args:
+        model (`torch.nn.Module`): The model in which to load the checkpoint.
+        folder (`str` or `os.PathLike`): A path to a folder containing the sharded checkpoint.
+        strict (`bool`, *optional*, defaults to `True`):
+            Whether to strictly enforce that the keys in the model state dict match the keys in the sharded checkpoint.
+        prefer_safe (`bool`, *optional*, defaults to `False`):
+            If both safetensors and PyTorch save files are present in checkpoint and `prefer_safe` is True, the
+            safetensors files will be loaded. Otherwise, PyTorch files are always loaded when possible.
+
+    Returns:
+        `NamedTuple`: A named tuple with `missing_keys` and `unexpected_keys` fields
+            - `missing_keys` is a list of str containing the missing keys
+            - `unexpected_keys` is a list of str containing the unexpected keys
+    """
+    # Load the index
+    index_file = os.path.join(folder, WEIGHTS_INDEX_NAME)
+    safe_index_file = os.path.join(folder, SAFE_WEIGHTS_INDEX_NAME)
+
+    index_present = os.path.isfile(index_file)
+    safe_index_present = os.path.isfile(safe_index_file)
+
+    if not index_present and not safe_index_present:
+        filenames = (WEIGHTS_INDEX_NAME, SAFE_WEIGHTS_INDEX_NAME)
+        raise ValueError(f"Can't find a checkpoint index ({' or '.join(filenames)}) in {folder}.")
+
+    load_safe = safe_index_present and (prefer_safe or not index_present)
+    load_index = safe_index_file if load_safe else index_file
+
+    with open(load_index, "r", encoding="utf-8") as f:
+        index = json.load(f)
+
+    shard_files = list(set(index["weight_map"].values()))
+
+    # If strict=True, error before loading any of the state dicts.
+    # TODO: Here, update the weight map with the config.dynamic_weight_conversion
+    loaded_keys = index["weight_map"].keys()
+    model_keys = model.state_dict().keys()
+    missing_keys = [key for key in model_keys if key not in loaded_keys]
+    unexpected_keys = [key for key in loaded_keys if key not in model_keys]
+    if strict and (len(missing_keys) > 0 or len(unexpected_keys) > 0):
+        error_message = f"Error(s) in loading state_dict for {model.__class__.__name__}"
+        if len(missing_keys) > 0:
+            str_missing_keys = ",".join([f'"{k}"' for k in missing_keys])
+            error_message += f"\nMissing key(s): {str_missing_keys}."
+        if len(unexpected_keys) > 0:
+            str_unexpected_keys = ",".join([f'"{k}"' for k in unexpected_keys])
+            error_message += f"\nMissing key(s): {str_unexpected_keys}."
+        raise RuntimeError(error_message)
+
+    if load_safe:
+        loader = safe_load_file
+    else:
+        check_torch_load_is_safe()
+        loader = partial(torch.load, map_location="cpu", weights_only=True)
+
+    for shard_file in shard_files:
+        state_dict = loader(os.path.join(folder, shard_file))
+        model.load_state_dict(state_dict, strict=False)
+
+        # Make sure memory is freed before we load the next state dict.
+        del state_dict
+        gc.collect()
+
+    # Return the same thing as PyTorch load_state_dict function.
+    return torch.nn.modules.module._IncompatibleKeys(missing_keys, unexpected_keys)
